<?php
// Start session and include database connection
session_start();
require_once "conn.php"; // Ensure this contains your PDO connection

// Redirect to login if not logged in
if (!isset($_SESSION['login'])) {
    $_SESSION['alert_message'] = "You need to log in as an Admin to gain access!";
    header("Location: admin_login.php");
    exit();
}

// Get the logged-in admin's username from session
$admin_username = $_SESSION['login'];
$admin = $_SESSION['admin_id'];

// Fetch the admin's ID
$getAdminID = $conn->prepare("SELECT id FROM admin WHERE username = :username");
$getAdminID->bindParam(':username', $admin_username, PDO::PARAM_STR);
$getAdminID->execute();
$adminData = $getAdminID->fetch(PDO::FETCH_ASSOC);

if (!$adminData) {
    die("Error: Admin not found.");
}

$admin_id = $adminData['id']; // Store admin's ID

// Get the chat partner's ID from URL
$chat_with = isset($_GET['chat_with']) ? intval($_GET['chat_with']) : null;

// Fetch all admins except the logged-in admin
$adminsQuery = $conn->prepare("SELECT id, username FROM admin WHERE id != :admin_id");
$adminsQuery->bindParam(':admin_id', $admin_id, PDO::PARAM_INT);
$adminsQuery->execute();
$admins = $adminsQuery->fetchAll(PDO::FETCH_ASSOC);

// Initialize messages array
$messages = [];

if ($chat_with && is_numeric($chat_with)) {
    // Mark messages as 'delivered'
    $updateDelivered = $conn->prepare("UPDATE admin_messages SET status = 'delivered' WHERE receiver_id = :admin_id AND sender_id = :chat_with AND status = 'sent'");
    $updateDelivered->bindParam(':admin_id', $admin_id, PDO::PARAM_INT);
    $updateDelivered->bindParam(':chat_with', $chat_with, PDO::PARAM_INT);
    $updateDelivered->execute();

    // Fetch messages
    $messagesQuery = $conn->prepare("SELECT m.*, a.username AS sender_name FROM admin_messages m JOIN admin a ON m.sender_id = a.id WHERE (m.receiver_id = :admin_id1 AND m.sender_id = :chat_with1) OR (m.sender_id = :admin_id2 AND m.receiver_id = :chat_with2) ORDER BY m.sent_at ASC");
    $messagesQuery->bindParam(':admin_id1', $admin_id, PDO::PARAM_INT);
    $messagesQuery->bindParam(':chat_with1', $chat_with, PDO::PARAM_INT);
    $messagesQuery->bindParam(':admin_id2', $admin_id, PDO::PARAM_INT);
    $messagesQuery->bindParam(':chat_with2', $chat_with, PDO::PARAM_INT);
    $messagesQuery->execute();
    $messages = $messagesQuery->fetchAll(PDO::FETCH_ASSOC);
}

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['send_message'])) {
    $message = trim($_POST['message']);
    $send_to_all = isset($_POST['send_to_all']) ? true : false;

    if (!empty($message)) {
        if ($send_to_all) {
            // Send message to all admins except the sender
            $getAllAdmins = $conn->prepare("SELECT id FROM admin WHERE id != :admin_id");
            $getAllAdmins->bindParam(':admin_id', $admin_id, PDO::PARAM_INT);
            $getAllAdmins->execute();
            $allAdmins = $getAllAdmins->fetchAll(PDO::FETCH_ASSOC);

            foreach ($allAdmins as $admin) {
                $insertMessage = $conn->prepare("INSERT INTO admin_messages (sender_id, receiver_id, message, sent_at, status) VALUES (:sender_id, :receiver_id, :message, NOW(), 'sent')");
                $insertMessage->bindParam(':sender_id', $admin_id, PDO::PARAM_INT);
                $insertMessage->bindParam(':receiver_id', $admin['id'], PDO::PARAM_INT);
                $insertMessage->bindParam(':message', $message, PDO::PARAM_STR);
                $insertMessage->execute();
            }
        } elseif ($chat_with) {
            // Send message to a specific admin
            $insertMessage = $conn->prepare("INSERT INTO admin_messages (sender_id, receiver_id, message, sent_at, status) VALUES (:sender_id, :receiver_id, :message, NOW(), 'sent')");
            $insertMessage->bindParam(':sender_id', $admin_id, PDO::PARAM_INT);
            $insertMessage->bindParam(':receiver_id', $chat_with, PDO::PARAM_INT);
            $insertMessage->bindParam(':message', $message, PDO::PARAM_STR);
            $insertMessage->execute();
        }

        // Refresh page to show new message
        header("Location: admin_chat.php?chat_with=" . $chat_with);
        exit();
    }
}


?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Super Admin Dashboard | RCCG</title>

    <!-- Dependencies -->
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="dist/css/custom.css">
    <link rel="stylesheet" href="dist/css/login_style.css">
    <link rel="stylesheet" href="assets/css/mystyle.css">
    <link rel="stylesheet" href="dist/css/animate.min.css">
    <link href="plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <!-- Include ApexCharts CSS -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.css">
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>


    <style>
        /* General Styling for the Cards */
.small-box {
    transition: transform 0.3s ease, box-shadow 0.3s ease;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
}

/* Add Hover Effect on Cards: Zoom Effect */
.small-box:hover {
    transform: scale(1.05); /* Zoom effect when hovering over the card */
    box-shadow: 0 8px 16px rgba(0, 0, 0, 0.2);
}

/* Animate cards when they appear on the screen */
@keyframes fadeInUp {
    0% {
        opacity: 0;
        transform: translateY(30px);
    }
    100% {
        opacity: 1;
        transform: translateY(0);
    }
}

.small-box {
    animation: fadeInUp 1s ease-out forwards;
}

/* Delayed animations for each card */
.col-lg-3.col-md-6.col-12:nth-child(1) .small-box {
    animation-delay: 0.1s;
}

.col-lg-3.col-md-6.col-12:nth-child(2) .small-box {
    animation-delay: 0.2s;
}

.col-lg-3.col-md-6.col-12:nth-child(3) .small-box {
    animation-delay: 0.3s;
}

.col-lg-3.col-md-6.col-12:nth-child(4) .small-box {
    animation-delay: 0.4s;
}

.col-lg-3.col-md-6.col-12:nth-child(5) .small-box {
    animation-delay: 0.5s;
}

.col-lg-3.col-md-6.col-12:nth-child(6) .small-box {
    animation-delay: 0.6s;
}

.col-lg-3.col-md-6.col-12:nth-child(7) .small-box {
    animation-delay: 0.7s;
}

        .dark-mode {
            background-color: #222;
            color: white;
        }

        .dark-mode .navbar,
        .dark-mode .main-footer,
        .dark-mode .main-sidebar {
            background-color: #333 !important;
            color: white !important;
        }

        .dark-mode .main-sidebar .nav-link,
        .dark-mode .main-sidebar .brand-link,
        .dark-mode .main-footer {
            color: white !important;
        }

        .dark-mode .dropdown-menu {
            background-color: #444 !important;
            color: white !important;
        }

        .dark-mode .dropdown-item {
            color: white !important;
        }

        .dark-mode .dropdown-item:hover {
            background-color: #555 !important;
        }

        /* Dark Mode - Make All Cards Black */
        .dark-mode .card {
            background-color: #1e1e1e !important;
            border-color: #333 !important;
            color: #fff !important;
        }

        /* Ensure charts remain visible */
        .dark-mode .chart-container canvas {
            background-color: #1e1e1e !important;
        }

        /* Change chart labels and data to white */
        .dark-mode .chartjs-render-monitor {
            color: #fff !important;
        }

        /* Ensure Pie Chart is properly sized */
        #pieChart {
            max-width: 100% !important;
            height: 250px !important;
        }

        /* Ensure all text is readable in charts */
        .dark-mode .chart-container text {
            fill: #ffffff !important;
        }

        /* Adjust the Card Body Height */
        .card-body {
            height: 300px;
        }

        /* Tables in Dark Mode */
        .dark-mode table {
            background-color: #1e1e1e !important;
            color: #ffffff !important;
        }

        .dark-mode th,
        .dark-mode td {
            border-color: #444 !important;
        }

        /* Ensure buttons remain visible */
        .dark-mode .btn {
            background-color: #333 !important;
            color: #fff !important;
            border-color: #555 !important;
        }

        /* Navbar links in dark mode */
        .dark-mode .navbar a {
            color: #fff !important;
        }

        /* Navbar Gradient */
        .navbar-gradient {
            background: linear-gradient(45deg, #003366, #990000);
            animation: gradient 5s infinite alternate;
        }

        @keyframes gradient {
            0% {
                background-position: left;
            }

            100% {
                background-position: right;
            }
        }

        /* Show dropdown on hover */
        .nav-item.dropdown:hover .dropdown-menu {
            display: block;
            margin-top: 0;
        }

        .profile-circle {
            width: 35px;
            height: 35px;
            background-color: #007bff;
            color: white;
            font-weight: bold;
            display: flex;
            align-items: center;
            justify-content: center;
            border-radius: 50%;
            font-size: 16px;
            text-transform: uppercase;
        }


        /* body { background-color: #f8f9fa; }
        .container { max-width: 900px; margin: 30px auto; }
        .chat-container { display: flex; border: 1px solid #ccc; border-radius: 10px; overflow: hidden; }
        .chat-list { width: 30%; background: #343a40; color: white; padding: 15px; }
        .chat-list h3 { color: #ffc107; }
        .chat-list ul { list-style: none; padding: 0; }
        .chat-list li { padding: 10px; border-bottom: 1px solid #495057; }
        .chat-list a { color: white; text-decoration: none; display: flex; align-items: center; }
        .chat-list a:hover { background: #495057; padding: 5px; border-radius: 5px; }
        .chat-box { width: 70%; padding: 15px; background: white; }
        .messages { height: 400px; overflow-y: auto; padding: 10px; border-bottom: 1px solid #ddd; }
        .chat-message { margin-bottom: 15px; padding: 10px; border-radius: 10px; max-width: 80%; }
        .sent { background:rgb(97, 171, 250); color: black; align-self: flex-end; text-align: right; }
        .received { background: #e9ecef; color: black; align-self: flex-start; text-align: left; }
        .message-status { font-size: 12px; display: block; margin-top: 5px; color: #6c757d; }
        .message-form { display: flex; margin-top: 10px; }
        .message-input { flex: 1; padding: 10px; border: 1px solid #ccc; border-radius: 5px; }
        .send-button { background: #28a745; color: white; border: none; padding: 10px 15px; border-radius: 5px; cursor: pointer; }
        .send-button:hover { background: #218838; } */

        body {
    background-color: #f8f9fa;
    font-family: Arial, sans-serif;
}

.container {
    max-width: 900px;
    margin: 30px auto;
}

.chat-container {
    display: flex;
    border-radius: 10px;
    overflow: hidden;
    height: 80vh;
    box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.1);
}

/* Admin List Sidebar */
.chat-list {
    width: 30%;
    background: #2C3E50;
    color: white;
    padding: 15px;
    overflow-y: auto;
}

.chat-list h3 {
    color: #1ABC9C;
}

.chat-list ul {
    list-style: none;
    padding: 0;
}

.chat-list li {
    padding: 10px;
    border-bottom: 1px solid #34495E;
}

.chat-list a {
    color: white;
    text-decoration: none;
    display: flex;
    align-items: center;
    padding: 10px;
    border-radius: 5px;
    transition: background 0.3s;
}

.chat-list a:hover,
.active-chat {
    background: #1ABC9C;
}

/* Chat Box */
.chat-box {
    width: 70%;
    display: flex;
    flex-direction: column;
    background: white;
    padding: 15px;
}

.messages {
    flex: 1;
    overflow-y: auto;
    padding: 10px;
    background: #ecf0f1;
    border-radius: 10px;
    display: flex;
    flex-direction: column;
}

/* Chat Bubbles */
.chat-message {
    max-width: 75%;
    padding: 10px;
    margin-bottom: 10px;
    border-radius: 15px;
    font-size: 14px;
    word-wrap: break-word;
}

.sent {
    background: #DCF8C6;
    align-self: flex-end;
    text-align: right;
    border-top-right-radius: 0;
}

.received {
    background: #fff;
    align-self: flex-start;
    text-align: left;
    border-top-left-radius: 0;
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
}

.message-status {
    font-size: 12px;
    display: block;
    margin-top: 5px;
    color: #6c757d;
}

/* Message Input */
.message-form {
    display: flex;
    margin-top: 10px;
    background: white;
    padding: 10px;
    border-top: 1px solid #ddd;
}

.message-input {
    flex: 1;
    padding: 12px;
    border: none;
    border-radius: 20px;
    background: #ecf0f1;
    outline: none;
    font-size: 14px;
}

.send-button {
    background: #1ABC9C;
    color: white;
    border: none;
    padding: 12px 18px;
    border-radius: 20px;
    cursor: pointer;
    margin-left: 10px;
    font-size: 14px;
}

.send-button:hover {
    background: #16A085;
}

    </style>
</head>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">
        <!-- Navbar -->
        <nav class="main-header navbar navbar-expand-lg navbar-light navbar-gradient">
            <div class="container-fluid">
                <!-- Left side -->
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarContent">
                    <i class="fas fa-bars text-white"></i>
                </button>

                <a href="#" class="navbar-brand text-white d-lg-none">Dashboard</a>

                <div class="collapse navbar-collapse" id="navbarContent">
                    <ul class="navbar-nav me-auto">
                        <li class="nav-item d-none d-lg-block">
                            <a href="#" class="nav-link text-white">Dashboard</a>
                        </li>
                    </ul>

                    <!-- Search bar (hidden on small screens) -->
                    <form class="d-none d-lg-flex form-inline mx-auto">
                        <input class="form-control me-3 px-3 py-2" type="search" placeholder="Search" aria-label="Search">
                        <button class="btn btn-outline-primary px-3 py-2" type="submit">
                            <i class="fas fa-search"></i>
                        </button>
                    </form>


                    <!-- Right side -->
                    <ul class="navbar-nav ms-auto">
                        <!-- Search button (for mobile) -->
                        <li class="nav-item d-lg-none">
                            <a class="nav-link text-white" href="#" data-bs-toggle="collapse" data-bs-target="#searchBar">
                                <i class="fas fa-search"></i>
                            </a>
                        </li>

                        <!-- Collapsible search bar for mobile -->
                        <div class="collapse" id="searchBar">
                            <form class="d-flex my-2">
                                <input class="form-control me-2" type="search" placeholder="Search">
                                <button class="btn btn-outline-primary" type="submit">
                                    <i class="fas fa-search"></i>
                                </button>
                            </form>
                        </div>


                        <!-- Language Selector with Nigerian Flag -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle text-white d-flex align-items-center" href="#" id="languageDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <img src="https://flagcdn.com/w40/ng.png" alt="Nigeria" width="25" class="me-3">
                                <span class="me-4 fw-bold">Nigeria</span> <!-- Increased spacing -->
                                <i class="fas fa-globe"></i> <span class="ms-3">Language</span> <!-- More space here -->
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="languageDropdown">
                                <li><a class="dropdown-item" href="#" data-lang="en">English</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="fr">French</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="es">Spanish</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="de">German</a></li>
                            </ul>
                        </li>



                        <!-- Dark mode toggle -->
                        <li class="nav-item">
                            <a class="nav-link text-white" id="toggleDarkMode">
                                <i class="fas fa-moon"></i>
                            </a>
                        </li>

                        <?php
                        // Get the username from the session
                        $username = isset($_SESSION['login']) ? $_SESSION['login'] : "Admin";

                        // Extract first and last letter (handle cases where username is too short)
                        $firstLetter = strtoupper($username[0]);
                        $lastLetter = strtoupper($username[strlen($username) - 1]);

                        // Profile initials
                        $profileInitials = $firstLetter . $lastLetter;
                        ?>

                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle text-white d-flex align-items-center" href="#" id="userDropdown" data-bs-toggle="dropdown">
                                <div class="profile-circle me-2"><?php echo $profileInitials; ?></div>
                                <span><?php echo ucfirst($username); ?></span>
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end">
                                <li><a class="dropdown-item" href="#">Profile</a></li>
                                <li><a class="dropdown-item" href="#">Settings</a></li>
                                <li>
                                    <hr class="dropdown-divider">
                                </li>
                                <li><a class="dropdown-item text-danger" href="logout.php">Logout</a></li>
                            </ul>
                        </li>

                    </ul>
                </div>
            </div>
        </nav>
    </div>


    

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // Dark Mode Toggle
        document.getElementById("toggleDarkMode").addEventListener("click", function() {
            document.body.classList.toggle("dark-mode");
        });
    </script>

    <style>
        /* Global Dark Mode Styles */
        .dark-mode {
            background-color: #121212;
            /* Dark background for page */
            color: white;
            /* White text color */
        }

        /* Dark Mode Body */
        .dark-mode body {
            background-color: #121212;
            /* Black background for body */
            color: white;
            /* White text */
        }

        /* Dark Mode Navbar */
        .dark-mode .navbar {
            background: #1f1f1f;
            /* Darker background for navbar */
        }

        /* Dark Mode Sidebar */
        .dark-mode .main-sidebar {
            background-color: #1f1f1f;
            /* Dark background for sidebar */
        }

        .dark-mode .brand-link {
            background-color: #1f1f1f;
            /* Dark background for the brand */
            color: white;
            /* White text color for brand */
        }

        .dark-mode .nav-link {
            color: white;
            /* White text for nav links */
        }

        .dark-mode .nav-link:hover {
            background-color: #333;
            /* Darker background on hover */
        }

        /* Dark Mode Form Controls */
        .dark-mode .form-control,
        .dark-mode .form-select {
            background-color: #333;
            color: white;
            border: 1px solid #555;
        }

        /* Dark Mode Button */
        .dark-mode .btn-outline-primary {
            border-color: white;
            color: white;
        }

        /* Dark Mode Dropdown */
        .dark-mode .dropdown-menu {
            background-color: #222;
        }

        .dark-mode .dropdown-item {
            color: white;
        }

        .dark-mode .dropdown-item:hover {
            background-color: #333;
        }

        /* Dark Mode Cards */
        .dark-mode .small-box {
            background-color: #333;
            /* Dark background for cards */
            color: white;
            /* White text color */
        }

        .dark-mode .small-box .inner h3 {
            font-weight: bold;
            color: white;
            /* Make the text inside the card white */
        }

        .dark-mode .small-box .icon i {
            color: white;
            /* White icons inside the card */
        }

        /* Footer Adjustment for Dark Mode */
        footer.main-footer {
            position: relative;
            bottom: 0;
            width: 100%;
            margin-top: 50px;
            /* Adjust this value depending on how much space you need */
        }
    </style>

    </style>

    <!-- Sidebar -->
    <?php include('sidebar.php'); ?>

    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <!-- Breadcrumb -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Dashboard</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="#">Home</a></li>
                            <li class="breadcrumb-item active">Dashboard</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->

        <div class="container">
        <h2 class="text-center text-primary fw-bold" style="font-size: 28px; text-shadow: 1px 1px 3px rgba(0, 0, 0, 0.2);">
    <i class="fas fa-comments text-success"></i> Admin Chat
</h2>

<div class="chat-container shadow-lg rounded">
    <!-- Admin List -->
    <div class="chat-list">
        <h3 class="text-warning fw-bold d-flex align-items-center">
            <i class="fas fa-user-friends me-2"></i> Admins
        </h3>

            <ul>
                <?php foreach ($admins as $admin): ?>
                    <li class="<?= ($chat_with == $admin['id']) ? 'active-chat' : ''; ?>">
                        <a href="admin_chat.php?chat_with=<?= $admin['id']; ?>">
                            <i class="fas fa-user-circle"></i> <?= htmlspecialchars($admin['username']); ?>
                        </a>
                    </li>
                <?php endforeach; ?>
            </ul>
        </div>
        
        <!-- Chat Box -->
        <div class="chat-box">
            <h3><i class="fas fa-comments"></i> Chat Messages</h3>
            <div class="messages" id="chat-messages">
                <?php if (!empty($messages)): ?>
                    <?php foreach ($messages as $msg): ?>
                        <div class="chat-message <?= ($msg['sender_id'] == $admin_id) ? 'sent' : 'received'; ?>">
                            <strong><?= htmlspecialchars($msg['sender_name']); ?>:</strong>
                            <p><?= nl2br(htmlspecialchars($msg['message'])); ?></p>
                            <small class="message-status">
                                <?= date('h:i A', strtotime($msg['sent_at'])); ?> - 
                                <?php if ($msg['status'] == 'sent'): ?>📩 Sent
                                <?php elseif ($msg['status'] == 'delivered'): ?>📬 Delivered
                                <?php else: ?>✔ Read
                                <?php endif; ?>
                            </small>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <p class="text-muted">No messages yet. Start a conversation!</p>
                <?php endif; ?>
            </div>
            
            <!-- Message Input -->
            <?php if ($chat_with): ?>
                <form method="post" class="message-form d-flex align-items-center p-2 rounded shadow-sm bg-light" id="message-form">
    <input type="text" name="message" id="message-input" class="form-control me-2 rounded-pill" 
           placeholder="Type a message..." required>

    <button type="button" id="send-to-all-btn" class="btn btn-outline-warning me-2 fw-bold" onclick="toggleSendToAll()">
        <i class="fas fa-bullhorn"></i> Send to All
    </button>

    <input type="hidden" name="send_to_all" id="send-to-all-input" value="0">

    <button type="submit" name="send_message" class="btn btn-success rounded-circle shadow-sm">
        <i class="fas fa-paper-plane"></i>
    </button>
</form>

<script>
    function toggleSendToAll() {
        let btn = document.getElementById("send-to-all-btn");
        let input = document.getElementById("send-to-all-input");
        
        if (input.value === "0") {
            input.value = "1";
            btn.classList.remove("btn-outline-warning");
            btn.classList.add("btn-warning");
            btn.innerHTML = '<i class="fas fa-bullhorn"></i> Sending to All';
        } else {
            input.value = "0";
            btn.classList.remove("btn-warning");
            btn.classList.add("btn-outline-warning");
            btn.innerHTML = '<i class="fas fa-bullhorn"></i> Send to All';
        }
    }
</script>



            <?php else: ?>
                <p class="text-center text-muted">Select an admin to chat with.</p>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- Auto-Scroll to Latest Message -->
<script>
    document.addEventListener("DOMContentLoaded", function () {
        let chatMessages = document.getElementById("chat-messages");
        
        // Scroll to the bottom when the page loads
        chatMessages.scrollTop = chatMessages.scrollHeight;
    });
</script>



        
        <?php
        include 'conn.php'; // Ensure this file contains your database connection

        // Fetch footer content from the footer table
        $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
        $footer = $stmt->fetch(PDO::FETCH_ASSOC);
        $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
        $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
        ?>
        <br><br>
        <footer class="text-sm">
            <div class="text-xs" id="copyright">
                <?php echo $copyrightMessage; ?>
                <div class="float-right d-none d-sm-inline-block">
                    <b><?php echo $eventInfo; ?></b>
                </div>
            </div>
        </footer>
    <!-- Modal -->
<div class="modal fade" id="welcomeModal" tabindex="-1" aria-labelledby="welcomeModalLabel" aria-hidden="true">
  <div class="modal-dialog modal-dialog-centered modal-lg"> <!-- Add modal-lg class for larger size -->
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title" id="welcomeModalLabel">Welcome to the New Admin Portal!</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" id="closeModalButton"></button>
      </div>
      <div class="modal-body">
        <p>We are excited to introduce the new features in the admin portal, giving you greater control and enhanced functionality. Here's what's new:</p>
        <ul>
          <li><strong>Total Control of All Convention Portals</strong> – Manage all convention portals from a single dashboard.</li>
          <li><strong>Approval of All Registrations</strong> – Full control over the approval process for registrations.</li>
          <li><strong>New User Interface</strong> – A sleek, user-friendly interface to enhance your experience.</li>
          <li><strong>General Report</strong> – Access to comprehensive reports to help you make informed decisions.</li>
          <li><strong>Create Admins, Provinces, Regions, and Assign Regions to Zones</strong> – Full administrative control over users and regions.</li>
          <li><strong>Create News and Notifications for All Coordinators</strong> – Easily manage news and notifications for all coordinators across the system.</li>
        </ul>
        <p>We hope you enjoy the enhanced experience and have all the tools you need to manage the portal effectively!</p>
      </div>
      <div class="modal-footer">
        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
        <button type="button" class="btn btn-primary">Got It!</button>
      </div>
    </div>
  </div>
</div>



<script>
  // Check if the modal has been closed previously using localStorage
  if (!localStorage.getItem('modalClosed')) {
    // Show the modal automatically when the page loads
    var myModal = new bootstrap.Modal(document.getElementById('welcomeModal'));
    myModal.show();
  }

  // Set the flag to not show the modal again once the user clicks close
  document.getElementById('closeModalButton').addEventListener('click', function() {
    localStorage.setItem('modalClosed', 'true');  // Store flag to prevent modal from showing again
  });
</script>


    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <!-- Scripts -->
    <script src="plugins/jquery/jquery.min.js"></script>
    <script src="plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
    <script src="plugins/sweetalert2/sweetalert2.min.js"></script>
    <script src="plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
    <script src="dist/js/adminlte.min.js"></script>
    <script defer src="scripts/cookies/cookieconsent.js"></script>
    <script defer src="scripts/cookies/cookieconsent-init.js"></script>
    <script src="plugins/jquery-validation/jquery.validate.min.js"></script>
    <script src="plugins/jquery-validation/additional-methods.min.js"></script>
    <!-- Include jQuery and Bootstrap JS -->

    
    <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>
  

    <!-- Scripts -->
    <script>
        // Function to toggle dark mode and save preference
        function toggleDarkMode() {
            $('body, .main-sidebar, .main-footer, .navbar, .card, .dropdown-menu, table, th, td').toggleClass('dark-mode');

            let isDarkMode = $('body').hasClass('dark-mode');

            // Store dark mode preference in localStorage
            localStorage.setItem('darkMode', isDarkMode ? 'enabled' : 'disabled');

            // Update icon
            let icon = $('#toggleDarkMode').find('i');
            icon.toggleClass('fa-moon fa-sun');
        }

        // Apply dark mode preference on page load
        $(document).ready(function() {
            if (localStorage.getItem('darkMode') === 'enabled') {
                $('body, .main-sidebar, .main-footer, .navbar, .card, .dropdown-menu, table, th, td').addClass('dark-mode');
                $('#toggleDarkMode').find('i').removeClass('fa-moon').addClass('fa-sun'); // Ensure correct icon
            }

            // Toggle dark mode on button click
            $('#toggleDarkMode').click(function() {
                toggleDarkMode();
            });

            // Language selector (no change needed)
            $('#languageSelector').change(function() {
                let selectedLanguage = $(this).val();
                alert("Language switched to: " + selectedLanguage);
                // You can integrate a translation API here.
            });
        });
    </script>

  

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>

</body>

</html>