<?php
// Start session and include database connection
session_start();
require_once "conn.php"; // Ensure this file contains your PDO connection setup

// Redirect to login if not logged in
if (!isset($_SESSION['login'])) {
    // Set the session variable for the alert message
    $_SESSION['alert_message'] = "You need to log in first!";

    // Redirect to the login page
    header("Location: admin_login.php");
    exit();
}
// Fetch total children, teens, teachers, and total amount generated from the registration table
$sql = "SELECT 
            SUM(p1c) AS total_children, 
            SUM(p2c) AS total_teens, 
            SUM(p3c) AS total_teachers, 
            SUM(amount) AS total_amount 
        FROM registration";
$stmt = $conn->prepare($sql);
$stmt->execute();
$result = $stmt->fetch(PDO::FETCH_ASSOC);

// Ensure the variables are always defined to prevent undefined variable warnings
$p1 = $result['total_children'] ?? 0;
$p2 = $result['total_teens'] ?? 0;
$p3 = $result['total_teachers'] ?? 0;
$p4 = number_format($result['total_amount'] ?? 0, 2); // Formatting amount with 2 decimal places

// Fetch approved and pending registrations from the `bank` table
$sql_approval = "SELECT 
    COUNT(CASE WHEN status = 'Approved' THEN 1 END) AS approved_count,
    COUNT(CASE WHEN status = 'Pending' THEN 1 END) AS pending_count
    FROM bank";
$stmt = $conn->prepare($sql_approval);
$stmt->execute();
$result = $stmt->fetch(PDO::FETCH_ASSOC);

$approved_count = $result['approved_count'] ?? 0;
$pending_count = $result['pending_count'] ?? 0;

// Calculate approval rate
$total_registrations = $approved_count + $pending_count;
// Calculate approval and pending rates
$approval_rate = ($total_registrations > 0) ? round(($approved_count / $total_registrations) * 100, 2) : 0;
$pending_rate = ($total_registrations > 0) ? round(($pending_count / $total_registrations) * 100, 2) : 0;

$currentYear = date('Y'); // Get the current year

// Query for Children Category
$query_children = "
    SELECT 
        SUM(children1) AS total_children1,
        SUM(children2) AS total_children2,
        SUM(children3) AS total_children3
    FROM children
    WHERE 
          year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = children.password 
              AND bank.status = 'Approved'
          )
";
$stmt_children = $conn->prepare($query_children);

$stmt_children->bindParam(':currentYear', $currentYear);
$stmt_children->execute();
$children_data = $stmt_children->fetch(PDO::FETCH_ASSOC);

// Query for Teens Category
$query_teens = "
    SELECT 
        SUM(teens1) AS total_teens1,
        SUM(teens2) AS total_teens2
    FROM teens
    WHERE 
           year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = teens.password 
              AND bank.status = 'Approved'
          )
";
$stmt_teens = $conn->prepare($query_teens);

$stmt_teens->bindParam(':currentYear', $currentYear);
$stmt_teens->execute();
$teens_data = $stmt_teens->fetch(PDO::FETCH_ASSOC);

// Query for Teachers Category
$query_teachers = "
    SELECT COUNT(*) AS total_teachers
    FROM teachers
    WHERE 
          year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = teachers.password 
              AND bank.status = 'Approved'
          )
";
$stmt_teachers = $conn->prepare($query_teachers);

$stmt_teachers->bindParam(':currentYear', $currentYear);
$stmt_teachers->execute();
$teachers_data = $stmt_teachers->fetch(PDO::FETCH_ASSOC);

// Query for Pending Registrations
$query_pending = "
    SELECT COUNT(*) AS total_pending
    FROM bank
    WHERE 
          status = 'Pending'
          AND year = :currentYear
";

try {
    $stmt_pending = $conn->prepare($query_pending);

    $stmt_pending->bindParam(':currentYear', $currentYear);
    $stmt_pending->execute();
    $pending_data = $stmt_pending->fetch(PDO::FETCH_ASSOC);

    if ($pending_data === false) {
        throw new Exception("Error fetching pending registrations.");
    }

    $total_pending = $pending_data['total_pending'];
} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
}

// Query for Approved Registrations
$query_approved = "
    SELECT COUNT(*) AS total_approved
    FROM bank
    WHERE 
          status = 'Approved'
          AND year = :currentYear
";

try {
    $stmt_approved = $conn->prepare($query_approved);

    $stmt_approved->bindParam(':currentYear', $currentYear);
    $stmt_approved->execute();
    $approved_data = $stmt_approved->fetch(PDO::FETCH_ASSOC);

    if ($approved_data === false) {
        throw new Exception("Error fetching approved registrations.");
    }

    $total_approved = $approved_data['total_approved'];
} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
}


?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Super Admin Dashboard | RCCG</title>

    <!-- Dependencies -->
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="dist/css/custom.css">
    <link rel="stylesheet" href="dist/css/login_style.css">
    <link rel="stylesheet" href="assets/css/mystyle.css">
    <link rel="stylesheet" href="dist/css/animate.min.css">
    <link href="plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <!-- Include ApexCharts CSS -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.css">
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>


    <style>
        /* General Styling for the Cards */
        .small-box {
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        /* Add Hover Effect on Cards: Zoom Effect */
        .small-box:hover {
            transform: scale(1.05);
            /* Zoom effect when hovering over the card */
            box-shadow: 0 8px 16px rgba(0, 0, 0, 0.2);
        }

        /* Animate cards when they appear on the screen */
        @keyframes fadeInUp {
            0% {
                opacity: 0;
                transform: translateY(30px);
            }

            100% {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .small-box {
            animation: fadeInUp 1s ease-out forwards;
        }

        /* Delayed animations for each card */
        .col-lg-3.col-md-6.col-12:nth-child(1) .small-box {
            animation-delay: 0.1s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(2) .small-box {
            animation-delay: 0.2s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(3) .small-box {
            animation-delay: 0.3s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(4) .small-box {
            animation-delay: 0.4s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(5) .small-box {
            animation-delay: 0.5s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(6) .small-box {
            animation-delay: 0.6s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(7) .small-box {
            animation-delay: 0.7s;
        }

        .dark-mode {
            background-color: #222;
            color: white;
        }

        .dark-mode .navbar,
        .dark-mode .main-footer,
        .dark-mode .main-sidebar {
            background-color: #333 !important;
            color: white !important;
        }

        .dark-mode .main-sidebar .nav-link,
        .dark-mode .main-sidebar .brand-link,
        .dark-mode .main-footer {
            color: white !important;
        }

        .dark-mode .dropdown-menu {
            background-color: #444 !important;
            color: white !important;
        }

        .dark-mode .dropdown-item {
            color: white !important;
        }

        .dark-mode .dropdown-item:hover {
            background-color: #555 !important;
        }

        /* Dark Mode - Make All Cards Black */
        .dark-mode .card {
            background-color: #1e1e1e !important;
            border-color: #333 !important;
            color: #fff !important;
        }

        /* Ensure charts remain visible */
        .dark-mode .chart-container canvas {
            background-color: #1e1e1e !important;
        }

        /* Change chart labels and data to white */
        .dark-mode .chartjs-render-monitor {
            color: #fff !important;
        }

        /* Ensure Pie Chart is properly sized */
        #pieChart {
            max-width: 100% !important;
            height: 250px !important;
        }

        /* Ensure all text is readable in charts */
        .dark-mode .chart-container text {
            fill: #ffffff !important;
        }

        /* Adjust the Card Body Height */
        .card-body {
            height: 300px;
        }

        /* Tables in Dark Mode */
        .dark-mode table {
            background-color: #1e1e1e !important;
            color: #ffffff !important;
        }

        .dark-mode th,
        .dark-mode td {
            border-color: #444 !important;
        }

        /* Ensure buttons remain visible */
        .dark-mode .btn {
            background-color: #333 !important;
            color: #fff !important;
            border-color: #555 !important;
        }

        /* Navbar links in dark mode */
        .dark-mode .navbar a {
            color: #fff !important;
        }

        /* Navbar Gradient */
        .navbar-gradient {
            background: linear-gradient(45deg, #003366, #990000);
            animation: gradient 5s infinite alternate;
        }

        @keyframes gradient {
            0% {
                background-position: left;
            }

            100% {
                background-position: right;
            }
        }

        /* Show dropdown on hover */
        .nav-item.dropdown:hover .dropdown-menu {
            display: block;
            margin-top: 0;
        }

        .profile-circle {
            width: 35px;
            height: 35px;
            background-color: #007bff;
            color: white;
            font-weight: bold;
            display: flex;
            align-items: center;
            justify-content: center;
            border-radius: 50%;
            font-size: 16px;
            text-transform: uppercase;
        }
    </style>
</head>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">
        <!-- Navbar -->
        <nav class="main-header navbar navbar-expand-lg navbar-light navbar-gradient">
            <div class="container-fluid">
                <!-- Left side -->
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarContent">
                    <i class="fas fa-bars text-white"></i>
                </button>

                <a href="#" class="navbar-brand text-white d-lg-none">Dashboard</a>

                <div class="collapse navbar-collapse" id="navbarContent">
                    <ul class="navbar-nav me-auto">
                        <li class="nav-item d-none d-lg-block">
                            <a href="#" class="nav-link text-white">Dashboard</a>
                        </li>
                    </ul>

                    <!-- Search bar (hidden on small screens) -->
                    <form class="d-none d-lg-flex form-inline mx-auto">
                        <input class="form-control me-3 px-3 py-2" type="search" placeholder="Search" aria-label="Search">
                        <button class="btn btn-outline-primary px-3 py-2" type="submit">
                            <i class="fas fa-search"></i>
                        </button>
                    </form>


                    <!-- Right side -->
                    <ul class="navbar-nav ms-auto">
                        <!-- Search button (for mobile) -->
                        <li class="nav-item d-lg-none">
                            <a class="nav-link text-white" href="#" data-bs-toggle="collapse" data-bs-target="#searchBar">
                                <i class="fas fa-search"></i>
                            </a>
                        </li>

                        <!-- Collapsible search bar for mobile -->
                        <div class="collapse" id="searchBar">
                            <form class="d-flex my-2">
                                <input class="form-control me-2" type="search" placeholder="Search">
                                <button class="btn btn-outline-primary" type="submit">
                                    <i class="fas fa-search"></i>
                                </button>
                            </form>
                        </div>


                        <!-- Language Selector with Nigerian Flag -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle text-white d-flex align-items-center" href="#" id="languageDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <img src="https://flagcdn.com/w40/ng.png" alt="Nigeria" width="25" class="me-3">
                                <span class="me-4 fw-bold">Nigeria</span> <!-- Increased spacing -->
                                <i class="fas fa-globe"></i> <span class="ms-3">Language</span> <!-- More space here -->
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="languageDropdown">
                                <li><a class="dropdown-item" href="#" data-lang="en">English</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="fr">French</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="es">Spanish</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="de">German</a></li>
                            </ul>
                        </li>



                        <!-- Dark mode toggle -->
                        <li class="nav-item">
                            <a class="nav-link text-white" id="toggleDarkMode">
                                <i class="fas fa-moon"></i>
                            </a>
                        </li>

                        <?php
                        // Get the username from the session
                        $username = isset($_SESSION['login']) ? $_SESSION['login'] : "Admin";

                        // Extract first and last letter (handle cases where username is too short)
                        $firstLetter = strtoupper($username[0]);
                        $lastLetter = strtoupper($username[strlen($username) - 1]);

                        // Profile initials
                        $profileInitials = $firstLetter . $lastLetter;
                        ?>

                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle text-white d-flex align-items-center" href="#" id="userDropdown" data-bs-toggle="dropdown">
                                <div class="profile-circle me-2"><?php echo $profileInitials; ?></div>
                                <span><?php echo ucfirst($username); ?></span>
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end">
                                <li><a class="dropdown-item" href="#">Profile</a></li>
                                <li><a class="dropdown-item" href="#">Settings</a></li>
                                <li>
                                    <hr class="dropdown-divider">
                                </li>
                                <li><a class="dropdown-item text-danger" href="logout.php">Logout</a></li>
                            </ul>
                        </li>

                    </ul>
                </div>
            </div>
        </nav>
    </div>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // Dark Mode Toggle
        document.getElementById("toggleDarkMode").addEventListener("click", function() {
            document.body.classList.toggle("dark-mode");
        });
    </script>

    <style>
        /* Global Dark Mode Styles */
        .dark-mode {
            background-color: #121212;
            /* Dark background for page */
            color: white;
            /* White text color */
        }

        /* Dark Mode Body */
        .dark-mode body {
            background-color: #121212;
            /* Black background for body */
            color: white;
            /* White text */
        }

        /* Dark Mode Navbar */
        .dark-mode .navbar {
            background: #1f1f1f;
            /* Darker background for navbar */
        }

        /* Dark Mode Sidebar */
        .dark-mode .main-sidebar {
            background-color: #1f1f1f;
            /* Dark background for sidebar */
        }

        .dark-mode .brand-link {
            background-color: #1f1f1f;
            /* Dark background for the brand */
            color: white;
            /* White text color for brand */
        }

        .dark-mode .nav-link {
            color: white;
            /* White text for nav links */
        }

        .dark-mode .nav-link:hover {
            background-color: #333;
            /* Darker background on hover */
        }

        /* Dark Mode Form Controls */
        .dark-mode .form-control,
        .dark-mode .form-select {
            background-color: #333;
            color: white;
            border: 1px solid #555;
        }

        /* Dark Mode Button */
        .dark-mode .btn-outline-primary {
            border-color: white;
            color: white;
        }

        /* Dark Mode Dropdown */
        .dark-mode .dropdown-menu {
            background-color: #222;
        }

        .dark-mode .dropdown-item {
            color: white;
        }

        .dark-mode .dropdown-item:hover {
            background-color: #333;
        }

        /* Dark Mode Cards */
        .dark-mode .small-box {
            background-color: #333;
            /* Dark background for cards */
            color: white;
            /* White text color */
        }

        .dark-mode .small-box .inner h3 {
            font-weight: bold;
            color: white;
            /* Make the text inside the card white */
        }

        .dark-mode .small-box .icon i {
            color: white;
            /* White icons inside the card */
        }

        /* Footer Adjustment for Dark Mode */
        footer.main-footer {
            position: relative;
            bottom: 0;
            width: 100%;
            margin-top: 50px;
            /* Adjust this value depending on how much space you need */
        }
    </style>

    </style>

    <!-- Sidebar -->
    <?php include('sidebar.php'); ?>

    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <!-- Breadcrumb -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Dashboard</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="#">Home</a></li>
                            <li class="breadcrumb-item active">Dashboard</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->



        <?php
        // Ensure connection to your database exists before using $conn
        // Example:
        // $conn = new PDO("mysql:host=your_host;dbname=your_db", "your_user", "your_password");

        // Fetch the data
        $query = "SELECT 
    SUM(CASE WHEN status = 'Approved' THEN 1 ELSE 0 END) AS approved_count,
    SUM(CASE WHEN status = 'Pending' THEN 1 ELSE 0 END) AS pending_count,
    SUM(cash) AS total_cash
FROM bank";
        $stmt = $conn->prepare($query);
        $stmt->execute();
        $result = $stmt->fetch(PDO::FETCH_ASSOC);

        $approvedCount = $result['approved_count'] ?? 0;
        $pendingCount = $result['pending_count'] ?? 0;
        $totalCash = $result['total_cash'] ?? 0;
        ?>

        <?php
        // Define the displayColumn function
        function displayColumn($label, $value)
        {
            echo '<div class="col">
            <p class="text-muted mt-3">' . htmlspecialchars($label) . '</p>
            <h3 class="mb-0"><span>' . (!empty($value) ? htmlspecialchars($value) : '0') . '</span></h3>
          </div>';
        }
        ?>

        <!-- Section for charts -->
        <div class="container-fluid mt-5">
            <div class="col-12">
                <div class="section-title text-center">
                    <h3>Annual <span class="alternate">Convention Registration Analysis</span></h3>
                    <p><?php echo date('Y'); ?> General Registration Analysis</p>
                </div>
            </div>

            <div class="row">
                <!-- Left Column with Bar Chart (Larger) -->
                <div class="col-lg-8">
                    <div class="card">
                        <div class="card-body">
                            <div class="card-widgets">
                                <a href="javascript:;" onclick="location.reload();"><i class="ri-refresh-line"></i></a>
                                <a data-bs-toggle="collapse" href="#weeklysales-collapse" role="button" aria-expanded="false" aria-controls="weeklysales-collapse">
                                    <i class="ri-subtract-line"></i>
                                </a>
                                <a href="#" data-bs-toggle="remove"><i class="ri-close-line"></i></a>
                            </div>
                            <h5 class="header-title mb-0">CONVENTION REGISTRATION ANALYSIS (APPROVED REGISTRATIONS)</h5>

                            <div id="weeklysales-collapse" class="collapse pt-3 show">
                                <div dir="ltr">
                                    <div id="id-chart" class="apex-charts" data-colors="#3bc0c3,#1a2942,#d1d7d973"></div>
                                </div>

                                <div class="row text-center">
                                    <?php
                                    // Use the displayColumn function as you did above to display the data dynamically
                                    displayColumn('Children (1-5)', $children_data['total_children1'] ?? 0);
                                    displayColumn('Children (6-8)', $children_data['total_children2'] ?? 0);
                                    displayColumn('Children (9-12)', $children_data['total_children3'] ?? 0);
                                    displayColumn('Teens (13-15)', $teens_data['total_teens1'] ?? 0);
                                    displayColumn('Teens (16-above)', $teens_data['total_teens2'] ?? 0);
                                    displayColumn('Teachers', $teachers_data['total_teachers'] ?? 0);
                                    displayColumn('Pending', $pending_data['total_pending'] ?? 0);
                                    displayColumn('Approved', $approved_data['total_approved'] ?? 0);
                                    ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Right Column with Virtual Account Details (Smaller) -->
                <div class="col-lg-4">
                    <div class="card">
                        <div class="card-body">
                            <div class="card-widgets">
                                <a href="javascript:;" onclick="location.reload();"><i class="ri-refresh-line"></i></a>
                                <a data-bs-toggle="collapse" href="#yearly-sales-collapse" role="button" aria-expanded="false" aria-controls="yearly-sales-collapse">
                                    <i class="ri-subtract-line"></i>
                                </a>
                                <a href="#" data-bs-toggle="remove"><i class="ri-close-line"></i></a>
                            </div>
                            <h5 class="header-title mb-0">REGISTRATION STATUS REPORT</h5>

                            <div id="yearly-sales-collapse" class="collapse pt-3 show">
                                <div dir="ltr">
                                    <div id="yearly-sales-chart" class="apex-charts" data-colors="#3bc0c3,#1a2942,#d1d7d973"></div>
                                </div>
                                <div class="row text-center">
                                    <div class="col">
                                        <p class="text-muted mt-3 mb-2">Approved</p>
                                        <h4 class="mb-0"><?php echo $approvedCount; ?></h4>
                                    </div>
                                    <div class="col">
                                        <p class="text-muted mt-3 mb-2">Pending</p>
                                        <h4 class="mb-0"><?php echo $pendingCount; ?></h4>
                                    </div>
                                    <div class="col">
                                        <p class="text-muted mt-3 mb-2">Total Paid</p>
                                        <h4 class="mb-0">₦<?php echo number_format($totalCash, 2); ?></h4>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <br><br>


        <!-- Section Content -->
        <section class="content">
            <div class="container-fluid">
                <!-- Export Buttons -->
                <div class="row mb-3">
                    <div class="col-12 text-right">
                        <button class="btn btn-success" onclick="exportData('csv')">Export CSV</button>
                        <button class="btn btn-primary" onclick="exportData('excel')">Export Excel</button>
                        <button class="btn btn-danger" onclick="exportData('pdf')">Export PDF</button>
                    </div>
                </div>
                <h2 class="text-center mb-4">Convention Registration Main Report</h2>
                <div class="row">
                    <!-- Total Children Registered -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $p1; ?></h3>
                                <p>Total Children Registered (Approved)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Teens Registered -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $p2; ?></h3>
                                <p>Total Teens Registered (Approved)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Teachers Registered -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $p3; ?></h3>
                                <p>Total Teachers Registered (Approved)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-chalkboard-teacher"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Amount Generated -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <!-- Safely formatted and styled total amount -->
                                    <?php
                                    // Remove commas from the string and ensure it's a numeric value
                                    $p4 = preg_replace('/[^0-9.\-]/', '', $p4);  // Remove non-numeric characters except period and minus sign
                                    $p4 = floatval($p4); // Convert to a float

                                    // Now safely format the number and apply bold and white color styling
                                    echo '<span style="font-weight: bold; color: white;">₦ ' . number_format($p4, 2) . '</span>';
                                    ?>
                                </h3>
                                <p>Total Amount Generated</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-money-bill-wave"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Approved Registrations -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $approved_count; ?></h3>
                                <p>Total Approved Registrations</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-check-circle"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Pending Registrations -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $pending_count; ?></h3>
                                <p>Total Pending Registrations</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-clock"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Registrations -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $total_registrations; ?></h3>
                                <p>Total Registrations</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-users"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Approval Rate -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-secondary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $approval_rate; ?>%</h3>
                                <p>Approval Rate</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-chart-line"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Pending Rate -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $pending_rate; ?>%</h3>
                                <p>Pending Rate</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-hourglass-half"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the total number of provinces that have received notifications
                                    $queryNotificationProvinces = "
                    SELECT COUNT(DISTINCT province) 
                    FROM notifications 
                    WHERE province IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $notificationProvinces = $conn->query($queryNotificationProvinces)->fetchColumn();

                                    // Display the result
                                    echo $notificationProvinces;
                                    ?>
                                </h3>
                                <p>Total Provinces with Notification Messages Sent</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-bell"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the total number of provinces that have read the notifications
                                    $queryReadNotificationProvinces = "
                    SELECT COUNT(DISTINCT province) 
                    FROM notifications 
                    WHERE is_read = 1 AND province IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $readNotificationProvinces = $conn->query($queryReadNotificationProvinces)->fetchColumn();

                                    // Display the result
                                    echo $readNotificationProvinces;
                                    ?>
                                </h3>
                                <p>Provinces that Have Read Notification Messages</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-check-circle"></i>
                            </div>
                        </div>
                    </div>
                </div>

                <h2 class="text-center mb-4">Choir Registration Details</h2>
                <div class="row">
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of zones for "Teens" category in the choir table
                                    $queryTeensZone = "
                    SELECT COUNT(DISTINCT zone) 
                    FROM choir 
                    WHERE category = 'Teens' AND zone IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $teensZoneCount = $conn->query($queryTeensZone)->fetchColumn();

                                    // Display the result
                                    echo $teensZoneCount;
                                    ?>
                                </h3>
                                <p>Number of Zones for Teens Choir Registration </p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-map-marker-alt"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of zones for "Children" category in the choir table
                                    $queryChildrenZone = "
                    SELECT COUNT(DISTINCT zone) 
                    FROM choir 
                    WHERE category = 'Children' AND zone IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $childrenZoneCount = $conn->query($queryChildrenZone)->fetchColumn();

                                    // Display the result
                                    echo $childrenZoneCount;
                                    ?>
                                </h3>
                                <p>Number of Zones for Children Choir Registration </p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-map-marker-alt"></i>
                            </div>
                        </div>
                    </div>
                </div>



                <h2 class="text-center mb-4">Sports Participant Documentation Details</h2>
                <div class="row">
                    <!-- Card for Participants with Passport (.jpg/.jpeg) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of participants with passport images ending in .jpg or .jpeg
                                    $queryPassport = "
                            SELECT COUNT(*) 
                            FROM paticipants 
                            WHERE (passport LIKE '%.jpg' OR passport LIKE '%.jpeg')";

                                    // Execute the query and fetch the result
                                    $passportCount = $conn->query($queryPassport)->fetchColumn();

                                    // Display the result
                                    echo $passportCount;
                                    ?>
                                </h3>
                                <p>Participants with Passport (.jpg/.jpeg)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-passport"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Card for Participants with Birth Certificate (.jpg/.jpeg) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of participants with birth certificate images ending in .jpg or .jpeg
                                    $queryBirthCertificate = "
                            SELECT COUNT(*) 
                            FROM paticipants 
                            WHERE (birth_certificate LIKE '%.jpg' OR birth_certificate LIKE '%.jpeg')";

                                    // Execute the query and fetch the result
                                    $birthCertificateCount = $conn->query($queryBirthCertificate)->fetchColumn();

                                    // Display the result
                                    echo $birthCertificateCount;
                                    ?>
                                </h3>
                                <p>Participants with Birth Certificate (.jpg/.jpeg)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-certificate"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Card for Participants without Passport (.jpg/.jpeg) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of participants without a passport with .jpg or .jpeg extension
                                    $queryNoPassport = "
                            SELECT COUNT(*) 
                            FROM paticipants 
                            WHERE passport NOT LIKE '%.jpg' AND passport NOT LIKE '%.jpeg' AND passport IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $noPassportCount = $conn->query($queryNoPassport)->fetchColumn();

                                    // Display the result
                                    echo $noPassportCount;
                                    ?>
                                </h3>
                                <p>Participants without Passport (.jpg/.jpeg)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-times-circle"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Card for Participants without Birth Certificate (.jpg/.jpeg) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of participants without a birth certificate with .jpg or .jpeg extension
                                    $queryNoBirthCertificate = "
                            SELECT COUNT(*) 
                            FROM paticipants 
                            WHERE birth_certificate NOT LIKE '%.jpg' AND birth_certificate NOT LIKE '%.jpeg' AND birth_certificate IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $noBirthCertificateCount = $conn->query($queryNoBirthCertificate)->fetchColumn();

                                    // Display the result
                                    echo $noBirthCertificateCount;
                                    ?>
                                </h3>
                                <p>Participants without Birth Certificate (.jpg/.jpeg)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-times-circle"></i>
                            </div>
                        </div>
                    </div>



                    <!-- Card for Male Participants -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of male participants
                                    $queryMale = "SELECT COUNT(*) FROM paticipants WHERE gender = 'Male'";

                                    // Execute the query and fetch the result
                                    $maleCount = $conn->query($queryMale)->fetchColumn();

                                    // Display the result
                                    echo $maleCount;
                                    ?>
                                </h3>
                                <p>Total Male Participants</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-male"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Card for Female Participants -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-pink p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of female participants
                                    $queryFemale = "SELECT COUNT(*) FROM paticipants WHERE gender = 'Female'";

                                    // Execute the query and fetch the result
                                    $femaleCount = $conn->query($queryFemale)->fetchColumn();

                                    // Display the result
                                    echo $femaleCount;
                                    ?>
                                </h3>
                                <p>Total Female Participants</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-female"></i>
                            </div>


                        </div>
                    </div>
                    <?php
                    // Include the connection for your main database
                    require_once 'conn.php';

                    // Fetch the number of participants in age ranges 6-8, 9-12, 13-15, and 16-19 years
                    $queryAge6to8 = "SELECT COUNT(*) FROM paticipants WHERE age BETWEEN 6 AND 8";
                    $age6to8 = $conn->query($queryAge6to8)->fetchColumn();

                    $queryAge9to12 = "SELECT COUNT(*) FROM paticipants WHERE age BETWEEN 9 AND 12";
                    $age9to12 = $conn->query($queryAge9to12)->fetchColumn();

                    $queryAge13to15 = "SELECT COUNT(*) FROM paticipants WHERE age BETWEEN 13 AND 15";
                    $age13to15 = $conn->query($queryAge13to15)->fetchColumn();

                    $queryAge16to19 = "SELECT COUNT(*) FROM paticipants WHERE age BETWEEN 16 AND 19";
                    $age16to19 = $conn->query($queryAge16to19)->fetchColumn();

                    // Count the approved and pending participants registration
                    $queryApproved = "SELECT COUNT(*) FROM paticipants WHERE status = 'Approved'";
                    $approvedCount = $conn->query($queryApproved)->fetchColumn();

                    $queryPending = "SELECT COUNT(*) FROM paticipants WHERE status = 'Pending'";
                    $pendingCount = $conn->query($queryPending)->fetchColumn();

                    // Count the number of zones with registered participants
                    $queryZones = "SELECT COUNT(DISTINCT zone) FROM paticipants WHERE status = 'Approved'";
                    $zoneCount = $conn->query($queryZones)->fetchColumn();

                    ?>

                    <!-- Age 6-8 Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age6to8; ?></h3>
                                <p>Participants (Ages 6-8)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Age 9-12 Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age9to12; ?></h3>
                                <p>Participants (Ages 9-12)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Age 13-15 Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age13to15; ?></h3>
                                <p>Participants (Ages 13-15)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Age 16-19 Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age16to19; ?></h3>
                                <p>Participants (Ages 16-19)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Approved Participants Registration Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $approvedCount; ?></h3>
                                <p>Approved Participants Registration</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-check-circle"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Pending Participants Registration Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-secondary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $pendingCount; ?></h3>
                                <p>Pending Participants Registration</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-clock"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Zones with Registered Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $zoneCount; ?></h3>
                                <p>Zones with Registered Participants</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-globe"></i>
                            </div>
                        </div>
                    </div>

                </div>



                <?php
                // Include the database connection file
                require_once 'conn.php';
                ?>
                <h2 class="text-center mb-4">Convention Registration Data Anaysis</h2>
                <div class="row">
                    <!-- Total Children (Ages 1-5 yrs) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count children (Ages 1-5) with matching status
                                    $query1 = "SELECT COUNT(*) FROM children c 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = c.password AND b.status = 'Approved') 
                               AND c.children1 > 0";
                                    $result1 = $conn->query($query1)->fetchColumn();
                                    echo $result1;
                                    ?>
                                </h3>
                                <p>Total Children (Ages 1-5 yrs)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Children (Ages 6-8 yrs) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count children (Ages 6-8) with matching status
                                    $query2 = "SELECT COUNT(*) FROM children c 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = c.password AND b.status = 'Approved') 
                               AND c.children2 > 0";
                                    $result2 = $conn->query($query2)->fetchColumn();
                                    echo $result2;
                                    ?>
                                </h3>
                                <p>Total Children (Ages 6-8 yrs)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Children (Ages 9-12 yrs) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count children (Ages 9-12) with matching status
                                    $query3 = "SELECT COUNT(*) FROM children c 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = c.password AND b.status = 'Approved') 
                               AND c.children3 > 0";
                                    $result3 = $conn->query($query3)->fetchColumn();
                                    echo $result3;
                                    ?>
                                </h3>
                                <p>Total Children (Ages 9-12 yrs)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Teens (Ages 13-15 yrs) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count teens (Ages 13-15) with matching status
                                    $query4 = "SELECT COUNT(*) FROM teens t 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = t.password AND b.status = 'Approved') 
                               AND t.teens1 > 0";
                                    $result4 = $conn->query($query4)->fetchColumn();
                                    echo $result4;
                                    ?>
                                </h3>
                                <p>Total Teens (Ages 13-15 yrs)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Teens (Ages 16-above yrs) -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count teens (Ages 16-above) with matching status
                                    $query5 = "SELECT COUNT(*) FROM teens t 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = t.password AND b.status = 'Approved') 
                               AND t.teens2 > 0";
                                    $result5 = $conn->query($query5)->fetchColumn();
                                    echo $result5;
                                    ?>
                                </h3>
                                <p>Total Teens (Ages 16-above yrs)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Male Teachers -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count male teachers with matching status
                                    $query6 = "SELECT COUNT(*) FROM teachers t 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = t.password AND b.status = 'Approved') 
                               AND t.gender = 'Male'";
                                    $result6 = $conn->query($query6)->fetchColumn();
                                    echo $result6;
                                    ?>
                                </h3>
                                <p>Total Male Teachers</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-chalkboard-teacher"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Total Female Teachers -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-secondary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count female teachers with matching status
                                    $query7 = "SELECT COUNT(*) FROM teachers t 
                               WHERE EXISTS (SELECT 1 FROM bank b WHERE b.rrr = t.password AND b.status = 'Approved') 
                               AND t.gender = 'Female'";
                                    $result7 = $conn->query($query7)->fetchColumn();
                                    echo $result7;
                                    ?>
                                </h3>
                                <p>Total Female Teachers</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-chalkboard-teacher"></i>
                            </div>
                        </div>
                    </div>
                    <?php
                    // Include the database connection file
                    require_once 'conn.php';
                    ?>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the total number of admins
                                    $queryAdmin = "SELECT COUNT(*) FROM admin";
                                    // Execute the query and fetch the result
                                    $resultAdmin = $conn->query($queryAdmin)->fetchColumn();
                                    echo $resultAdmin;
                                    ?>
                                </h3>
                                <p>Total Admins</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-shield"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of zones in the province table
                                    $queryZones = "SELECT COUNT(DISTINCT zone) FROM province";
                                    // Execute the query and fetch the result
                                    $resultZones = $conn->query($queryZones)->fetchColumn();
                                    echo $resultZones;
                                    ?>
                                </h3>
                                <p>Total Zones</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-map-marker-alt"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of provinces
                                    $queryProvinces = "SELECT COUNT(DISTINCT province) FROM province";
                                    // Execute the query and fetch the result
                                    $resultProvinces = $conn->query($queryProvinces)->fetchColumn();
                                    echo $resultProvinces;
                                    ?>
                                </h3>
                                <p>Total Provinces</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-globe-africa"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of regions in the province table
                                    $queryRegions = "SELECT COUNT(DISTINCT region) FROM province";
                                    // Execute the query and fetch the result
                                    $resultRegions = $conn->query($queryRegions)->fetchColumn();
                                    echo $resultRegions;
                                    ?>
                                </h3>
                                <p>Total Regions</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-globe"></i>
                            </div>
                        </div>
                    </div>
                    <?php
                    // Include the database connection file
                    require_once 'conn.php';
                    ?>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of provinces that have registered in the registration table
                                    // and match with the status in the bank table
                                    $queryRegisteredProvinces = "
                    SELECT COUNT(DISTINCT r.province) 
                    FROM registration r
                    JOIN bank b ON r.password = b.rrr
                    WHERE b.status = 'Approved' AND r.province IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $resultRegisteredProvinces = $conn->query($queryRegisteredProvinces)->fetchColumn();
                                    echo $resultRegisteredProvinces;
                                    ?>
                                </h3>
                                <p>Number of Provinces with Approved Registration</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-flag"></i>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to count the number of provinces with pending registration
                                    $queryPendingProvinces = "
                    SELECT COUNT(DISTINCT r.province) 
                    FROM registration r
                    JOIN bank b ON r.password = b.rrr
                    WHERE b.status = 'Pending' AND r.province IS NOT NULL";

                                    // Execute the query and fetch the result
                                    $resultPendingProvinces = $conn->query($queryPendingProvinces)->fetchColumn();
                                    echo $resultPendingProvinces;
                                    ?>
                                </h3>
                                <p>Number of Provinces with Pending Registration</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-hourglass-half"></i>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to get the total number of provinces from the province table
                                    $queryTotalProvinces = "SELECT COUNT(DISTINCT province) FROM province";
                                    $totalProvinces = $conn->query($queryTotalProvinces)->fetchColumn();

                                    // Query to get the count of provinces that have registered in the registration table with the bank status
                                    $queryRegisteredProvinces = "
                    SELECT COUNT(DISTINCT r.province) 
                    FROM registration r
                    JOIN bank b ON r.password = b.rrr
                    WHERE b.status = 'Approved' AND r.province IS NOT NULL";

                                    $registeredProvinces = $conn->query($queryRegisteredProvinces)->fetchColumn();

                                    // Calculate the registration rate as a percentage
                                    if ($totalProvinces > 0) {
                                        $registrationRate = ($registeredProvinces / $totalProvinces) * 100;
                                    } else {
                                        $registrationRate = 0;
                                    }

                                    // Display the registration rate
                                    echo number_format($registrationRate, 2) . '%';
                                    ?>
                                </h3>
                                <p>Province with Approved Registration Rate</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-percentage"></i>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3>
                                    <?php
                                    // Query to get the total number of provinces from the province table
                                    $queryTotalProvinces = "SELECT COUNT(DISTINCT province) FROM province";
                                    $totalProvinces = $conn->query($queryTotalProvinces)->fetchColumn();

                                    // Query to get the count of provinces that have registered in both the registration and bank tables
                                    $queryRegisteredProvinces = "
                    SELECT COUNT(DISTINCT r.province) 
                    FROM registration r
                    JOIN bank b ON r.password = b.rrr
                    WHERE r.province IS NOT NULL AND b.rrr IS NOT NULL";

                                    $registeredProvinces = $conn->query($queryRegisteredProvinces)->fetchColumn();

                                    // Calculate the registration rate as a percentage
                                    if ($totalProvinces > 0) {
                                        $registrationRate = ($registeredProvinces / $totalProvinces) * 100;
                                    } else {
                                        $registrationRate = 0;
                                    }

                                    // Display the registration rate
                                    echo number_format($registrationRate, 2) . '%';
                                    ?>
                                </h3>
                                <p>Province Registration Rate</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-percentage"></i>
                            </div>
                        </div>
                    </div>
                </div>



                <?php
                // Include the connection for your main database
                require_once 'conn.php';

                // Include the connection for the quiz database
                $quizConn = new PDO('mysql:host=localhost;dbname=quiz', 'root', '');

                // Set the PDO error mode to exception for better error handling
                $quizConn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

                // Now, proceed to fetch records for each card:

                // 1. Number of Male and Female Participants
                $queryMale = "SELECT COUNT(*) FROM participants WHERE gender = 'Male'";
                $maleCount = $quizConn->query($queryMale)->fetchColumn();

                $queryFemale = "SELECT COUNT(*) FROM participants WHERE gender = 'Female'";
                $femaleCount = $quizConn->query($queryFemale)->fetchColumn();

                // 2. Number of Participants with Passport Image (JPEG/JPG)
                $queryPassport = "SELECT COUNT(*) FROM participants WHERE passport_image LIKE '%.jpg' OR passport_image LIKE '%.jpeg'";
                $passportCount = $quizConn->query($queryPassport)->fetchColumn();

                // 3. Number of Participants with Birth Certificate Image (JPEG/JPG)
                $queryBirthCertificate = "SELECT COUNT(*) FROM participants WHERE birth_certificate_image LIKE '%.jpg' OR birth_certificate_image LIKE '%.jpeg'";
                $birthCertificateCount = $quizConn->query($queryBirthCertificate)->fetchColumn();

                // 4. Number of Participants whose Passport and Certificate are NOT in JPEG/JPG format
                $queryInvalidImages = "SELECT COUNT(*) FROM participants WHERE (passport_image NOT LIKE '%.jpg' AND passport_image NOT LIKE '%.jpeg') AND (birth_certificate_image NOT LIKE '%.jpg' AND birth_certificate_image NOT LIKE '%.jpeg')";
                $invalidImageCount = $quizConn->query($queryInvalidImages)->fetchColumn();

                // 5. Number of Participants by Age Groups (6-8 years, 9-12 years, 13-15 years, 16-19 years)
                $queryAge6to8 = "SELECT COUNT(*) FROM participants WHERE age_year BETWEEN 6 AND 8";
                $age6to8 = $quizConn->query($queryAge6to8)->fetchColumn();

                $queryAge9to12 = "SELECT COUNT(*) FROM participants WHERE age_year BETWEEN 9 AND 12";
                $age9to12 = $quizConn->query($queryAge9to12)->fetchColumn();

                $queryAge13to15 = "SELECT COUNT(*) FROM participants WHERE age_year BETWEEN 13 AND 15";
                $age13to15 = $quizConn->query($queryAge13to15)->fetchColumn();

                $queryAge16to19 = "SELECT COUNT(*) FROM participants WHERE age_year BETWEEN 16 AND 19";
                $age16to19 = $quizConn->query($queryAge16to19)->fetchColumn();

                // 6. Count of Participants with Status 'Activated' and 'Pending'
                $queryActivated = "SELECT COUNT(*) FROM participants WHERE status = 'Activated'";
                $activatedCount = $quizConn->query($queryActivated)->fetchColumn();

                $queryPending = "SELECT COUNT(*) FROM participants WHERE status = 'Pending'";
                $pendingCount = $quizConn->query($queryPending)->fetchColumn();

                // 7. Number of Registered Participants by Zone
                $queryZone = "SELECT COUNT(DISTINCT zone) FROM participants WHERE status = 'Activated'";
                $zoneCount = $quizConn->query($queryZone)->fetchColumn();

                ?>

                <!-- Display the Cards -->


                <h2 class="text-center mb-4">Quiz Competition Participants Detials</h2>
                <div class="row">

                    <!-- Male Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $maleCount; ?></h3>
                                <p>Total Male Participants</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-male"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Female Participants Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-pink p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $femaleCount; ?></h3>
                                <p>Total Female Participants</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-female"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Passport Image (JPEG/JPG) Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $passportCount; ?></h3>
                                <p>Participants with Passport Image (JPEG/JPG)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-id-card"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Birth Certificate Image (JPEG/JPG) Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $birthCertificateCount; ?></h3>
                                <p>Participants with Birth Certificate Image (JPEG/JPG)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-certificate"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Invalid Images Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $invalidImageCount; ?></h3>
                                <p>Participants with Invalid Passport and Certificate Image</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-ban"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Age Group Cards -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age6to8; ?></h3>
                                <p>Participants (Ages 6-8)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age9to12; ?></h3>
                                <p>Participants (Ages 9-12)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-child"></i>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-success p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age13to15; ?></h3>
                                <p>Participants (Ages 13-15)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $age16to19; ?></h3>
                                <p>Participants (Ages 16-19)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-user-friends"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Status Cards -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-primary p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $activatedCount; ?></h3>
                                <p>Approved Participants Registration</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-check-circle"></i>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-danger p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $pendingCount; ?></h3>
                                <p>Pending Participants Registration</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-clock"></i>
                            </div>
                        </div>
                    </div>

                    <!-- Zone Count Card -->
                    <div class="col-lg-3 col-md-6 col-12">
                        <div class="small-box bg-info p-4 rounded">
                            <div class="inner">
                                <h3><?php echo $zoneCount; ?></h3>
                                <p>Zones with Registered Participants</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-globe"></i>
                            </div>
                        </div>
                    </div>

        </section>





        <?php
        include 'conn.php'; // Ensure this file contains your database connection

        // Fetch footer content from the footer table
        $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
        $footer = $stmt->fetch(PDO::FETCH_ASSOC);
        $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
        $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
        ?>
        <br><br>
        <footer class="text-sm">
            <div class="text-xs" id="copyright">
                <?php echo $copyrightMessage; ?>
                <div class="float-right d-none d-sm-inline-block">
                    <b><?php echo $eventInfo; ?></b>
                </div>
            </div>
        </footer>
        <!-- Modal -->
        <div class="modal fade" id="welcomeModal" tabindex="-1" aria-labelledby="welcomeModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered modal-lg"> <!-- Add modal-lg class for larger size -->
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="welcomeModalLabel">Welcome to the New Admin Portal!</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" id="closeModalButton"></button>
                    </div>
                    <div class="modal-body">
                        <p>We are excited to introduce the new features in the admin portal, giving you greater control and enhanced functionality. Here's what's new:</p>
                        <ul>
                            <li><strong>Total Control of All Convention Portals</strong> – Manage all convention portals from a single dashboard.</li>
                            <li><strong>Approval of All Registrations</strong> – Full control over the approval process for registrations.</li>
                            <li><strong>New User Interface</strong> – A sleek, user-friendly interface to enhance your experience.</li>
                            <li><strong>General Report</strong> – Access to comprehensive reports to help you make informed decisions.</li>
                            <li><strong>Create Admins, Provinces, Regions, and Assign Regions to Zones</strong> – Full administrative control over users and regions.</li>
                            <li><strong>Create News and Notifications for All Coordinators</strong> – Easily manage news and notifications for all coordinators across the system.</li>
                        </ul>
                        <p>We hope you enjoy the enhanced experience and have all the tools you need to manage the portal effectively!</p>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                        <button type="button" class="btn btn-primary">Got It!</button>
                    </div>
                </div>
            </div>
        </div>

        <!-- Bootstrap JS and dependencies -->
        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.min.js"></script>

        <script>
            // Check if the modal has been closed previously using localStorage
            if (!localStorage.getItem('modalClosed')) {
                // Show the modal automatically when the page loads
                var myModal = new bootstrap.Modal(document.getElementById('welcomeModal'));
                myModal.show();
            }

            // Set the flag to not show the modal again once the user clicks close
            document.getElementById('closeModalButton').addEventListener('click', function() {
                localStorage.setItem('modalClosed', 'true'); // Store flag to prevent modal from showing again
            });
        </script>


        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
        <!-- Scripts -->
        <script src="plugins/jquery/jquery.min.js"></script>
        <script src="plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
        <script src="plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
        <script src="plugins/sweetalert2/sweetalert2.min.js"></script>
        <script src="plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
        <script src="dist/js/adminlte.min.js"></script>
        <script defer src="scripts/cookies/cookieconsent.js"></script>
        <script defer src="scripts/cookies/cookieconsent-init.js"></script>
        <script src="plugins/jquery-validation/jquery.validate.min.js"></script>
        <script src="plugins/jquery-validation/additional-methods.min.js"></script>
        <!-- Include jQuery and Bootstrap JS -->


        <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>


        <!-- Scripts -->
        <script>
            // Function to toggle dark mode and save preference
            function toggleDarkMode() {
                $('body, .main-sidebar, .main-footer, .navbar, .card, .dropdown-menu, table, th, td').toggleClass('dark-mode');

                let isDarkMode = $('body').hasClass('dark-mode');

                // Store dark mode preference in localStorage
                localStorage.setItem('darkMode', isDarkMode ? 'enabled' : 'disabled');

                // Update icon
                let icon = $('#toggleDarkMode').find('i');
                icon.toggleClass('fa-moon fa-sun');
            }

            // Apply dark mode preference on page load
            $(document).ready(function() {
                if (localStorage.getItem('darkMode') === 'enabled') {
                    $('body, .main-sidebar, .main-footer, .navbar, .card, .dropdown-menu, table, th, td').addClass('dark-mode');
                    $('#toggleDarkMode').find('i').removeClass('fa-moon').addClass('fa-sun'); // Ensure correct icon
                }

                // Toggle dark mode on button click
                $('#toggleDarkMode').click(function() {
                    toggleDarkMode();
                });

                // Language selector (no change needed)
                $('#languageSelector').change(function() {
                    let selectedLanguage = $(this).val();
                    alert("Language switched to: " + selectedLanguage);
                    // You can integrate a translation API here.
                });
            });
        </script>

        <script>
            // Bar Chart
            var ctxBar = document.getElementById('barChart').getContext('2d');
            new Chart(ctxBar, {
                type: 'bar',
                data: {
                    labels: ['January', 'February', 'March', 'April', 'May'],
                    datasets: [{
                        label: 'Registrations',
                        data: [50, 80, 60, 90, 100],
                        backgroundColor: 'rgba(54, 162, 235, 0.6)'
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false
                }
            });

            // Line Chart
            var ctxLine = document.getElementById('lineChart').getContext('2d');
            new Chart(ctxLine, {
                type: 'line',
                data: {
                    labels: ['January', 'February', 'March', 'April', 'May'],
                    datasets: [{
                        label: 'Approval Rate (%)',
                        data: [75, 85, 80, 90, 95],
                        borderColor: 'rgba(75, 192, 192, 1)',
                        fill: false
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false
                }
            });

            // Pie Chart (Smaller Size)
            var ctxPie = document.getElementById('pieChart').getContext('2d');
            new Chart(ctxPie, {
                type: 'pie',
                data: {
                    labels: ['Approved', 'Pending'],
                    datasets: [{
                        data: [85, 15],
                        backgroundColor: ['rgba(40, 167, 69, 0.6)', 'rgba(255, 193, 7, 0.6)']
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false
                }
            });
        </script>
        <script>
            function exportData(format) {
                window.location.href = 'export.php?format=' + format;
            }
        </script>
        <script>
            // Data fetched from PHP
            var children1 = <?php echo json_encode($children_data['total_children1']); ?>;
            var children2 = <?php echo json_encode($children_data['total_children2']); ?>;
            var children3 = <?php echo json_encode($children_data['total_children3']); ?>;
            var teens1 = <?php echo json_encode($teens_data['total_teens1']); ?>;
            var teens2 = <?php echo json_encode($teens_data['total_teens2']); ?>;
            var teachers = <?php echo json_encode($teachers_data['total_teachers']); ?>;
            var pending = <?php echo json_encode($pending_data['total_pending']); ?>;
            var approved = <?php echo json_encode($approved_data['total_approved']); ?>;

            // Bar Chart for DTCE TEACHERS IDENTITY CARDS REPORT
            var options = {
                chart: {
                    type: 'bar',
                    height: 350
                },
                series: [{
                    name: 'Children (1-5)',
                    data: [children1]
                }, {
                    name: 'Children (6-8)',
                    data: [children2]
                }, {
                    name: 'Children (9-12)',
                    data: [children3]
                }, {
                    name: 'Teens (13-15)',
                    data: [teens1]
                }, {
                    name: 'Teens (16-above)',
                    data: [teens2]
                }, {
                    name: 'Teachers',
                    data: [teachers]
                }, {
                    name: 'Pending Reg.',
                    data: [pending]
                }, {
                    name: 'Approved Reg.',
                    data: [approved]
                }],
                xaxis: {
                    categories: ['Children (1-5)', 'Children (6-8)', 'Children (9-12)', 'Teens (13-15)', 'Teens (16-above)',
                        'Teachers', 'Pending Reg.', 'Approved Reg.'
                    ]
                },
                colors: ['#3bc0c3', '#1a2942', '#d1d7d9', '#ff4560', '#00e396', '#00e396', '#FFC107', '#28A745']
            };

            var chart = new ApexCharts(document.querySelector("#id-chart"), options);
            chart.render();

            // Line Chart for Monthly Junior Church Attendance Report
            var approvedCount = parseInt(<?php echo json_encode($approvedCount); ?>);
            var pendingCount = parseInt(<?php echo json_encode($pendingCount); ?>);
            var totalCash = parseFloat(<?php echo json_encode($totalCash); ?>);

            // Debugging to check if data is passed correctly
            console.log("Approved Count (int):", approvedCount);
            console.log("Pending Count (int):", pendingCount);
            console.log("Total Cash (float):", totalCash);

            // Update Line Chart for Registrations
            var options2 = {
                chart: {
                    type: 'line',
                    height: 350
                },
                series: [{
                    name: 'Registrations',
                    data: [approvedCount, pendingCount, totalCash] // Data for Approved, Pending, and Total Cash
                }],
                xaxis: {
                    categories: ['Approved', 'Pending', 'Total Cash']
                },
                colors: ['#3bc0c3']
            };

            // Initialize and render the chart
            var chart2 = new ApexCharts(document.querySelector("#yearly-sales-chart"), options2);
            chart2.render();
        </script>



        <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>

</body>

</html>