<?php
// Include database connection
include('conn.php');

if (isset($_GET['id'])) {
    // Download a single record
    $id = $_GET['id'];

    $query = "SELECT * FROM province WHERE id = :id";
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
    $stmt->execute();
    $record = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($record) {
        // Set filename
        $filename = "Province_Record_" . $record['id'] . ".csv";
        
        // Set headers for CSV download
        header('Content-Type: text/csv');
        header('Content-Disposition: attachment; filename="' . $filename . '"');

        // Open output buffer
        $output = fopen('php://output', 'w');

        // Add CSV headers
        fputcsv($output, ['ID', 'Zone', 'Province', 'Region', 'Password', 'Password Changed', 'Status']);

        // Add record data
        fputcsv($output, [
            $record['id'], 
            $record['zone'], 
            $record['province'], 
            $record['region'], 
            $record['password'], 
            $record['password_changed'] ? 'Yes' : 'No', 
            $record['status']
        ]);

        fclose($output);
        exit;
    } else {
        echo "Record not found.";
    }
} elseif (isset($_GET['zone'])) {
    // Download multiple records for a specific zone
    $zone = $_GET['zone'];

    $query = "SELECT * FROM province WHERE zone = :zone";
    $stmt = $conn->prepare($query);
    $stmt->bindParam(':zone', $zone, PDO::PARAM_STR);
    $stmt->execute();
    $records = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if ($records) {
        // Set filename
        $filename = "Province_Records_Zone_" . str_replace(' ', '_', $zone) . ".csv";
        
        // Set headers for CSV download
        header('Content-Type: text/csv');
        header('Content-Disposition: attachment; filename="' . $filename . '"');

        // Open output buffer
        $output = fopen('php://output', 'w');

        // Add CSV headers
        fputcsv($output, ['ID', 'Zone', 'Province', 'Region', 'Password', 'Password Changed', 'Status']);

        // Add records to CSV
        foreach ($records as $record) {
            fputcsv($output, [
                $record['id'], 
                $record['zone'], 
                $record['province'], 
                $record['region'], 
                $record['password'], 
                $record['password_changed'] ? 'Yes' : 'No', 
                $record['status']
            ]);
        }

        fclose($output);
        exit;
    } else {
        echo "No records found for this zone.";
    }
} else {
    echo "Invalid request.";
}
?>
