<?php
require 'conn.php'; // Database connection
require_once('tcpdf/tcpdf.php'); // Include TCPDF library

if (isset($_GET['format'])) {
    $format = $_GET['format'];

    // Fetch detailed registration records
    $query = $conn->query("SELECT * FROM registration"); 
    $data = $query->fetchAll(PDO::FETCH_ASSOC);

    // Ensure data is an empty array if no records are found
    if (!$data) {
        $data = [];
    }

    // Fetch summary statistics
    $sql = "SELECT 
                SUM(p1c) AS total_children, 
                SUM(p2c) AS total_teens, 
                SUM(p3c) AS total_teachers, 
                SUM(amount) AS total_amount 
            FROM registration";
    $stmt = $conn->prepare($sql);
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    $p1 = $result['total_children'] ?? 0;
    $p2 = $result['total_teens'] ?? 0;
    $p3 = $result['total_teachers'] ?? 0;
    $p4 = number_format($result['total_amount'] ?? 0, 2);

    // Fetch approved and pending registrations from the `bank` table
    $sql_approval = "SELECT 
        COUNT(CASE WHEN status = 'Approved' THEN 1 END) AS approved_count,
        COUNT(CASE WHEN status = 'Pending' THEN 1 END) AS pending_count
        FROM bank";
    $stmt = $conn->prepare($sql_approval);
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    $approved_count = $result['approved_count'] ?? 0;
    $pending_count = $result['pending_count'] ?? 0;
    $total_registrations = $approved_count + $pending_count;
    $approval_rate = ($total_registrations > 0) ? round(($approved_count / $total_registrations) * 100, 2) : 0;

    if ($format == 'csv') {
        // Clear output buffer to prevent extra spaces from breaking CSV
        ob_clean();
        
        // Set headers for CSV download
        header('Content-Type: text/csv; charset=UTF-8');
        header('Content-Disposition: attachment; filename="registrations.csv"');
    
        // Open output stream
        $output = fopen("php://output", "w");
        
        // Set UTF-8 BOM for Excel compatibility (optional)
        fputs($output, "\xEF\xBB\xBF"); 
        
        // Write summary statistics
        fputcsv($output, ['Total Children', 'Total Teens', 'Total Teachers', 'Total Amount Generated', 'Total Approved', 'Total Pending', 'Approval Rate (%)']);
        fputcsv($output, [$p1, $p2, $p3, $p4, $approved_count, $pending_count, $approval_rate]);
        fputcsv($output, []); // Blank row
        
        // Write column headers if data exists
        if (!empty($data)) {
            fputcsv($output, array_keys($data[0])); // Column headers
            foreach ($data as $row) {
                fputcsv($output, $row);
            }
        } else {
            fputcsv($output, ['No data available']);
        }
        
        // Close output and exit
        fclose($output);
        exit;
    }
    elseif ($format == 'excel') {
        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment; filename="registrations.xls"');

        // Summary
        echo "Total Children\tTotal Teens\tTotal Teachers\tTotal Amount Generated\tTotal Approved\tTotal Pending\tApproval Rate (%)\n";
        echo "$p1\t$p2\t$p3\t$p4\t$approved_count\t$pending_count\t$approval_rate%\n\n";

        // Detailed Data
        // echo implode("\t", array_keys($data[0])) . "\n";
        // foreach ($data as $row) {
        //     echo implode("\t", array_values($row)) . "\n";
        // }
        // exit;
    }
    

    if ($format == 'pdf') {
        // Create new PDF document
        $pdf = new TCPDF();
        $pdf->SetCreator(PDF_CREATOR);
        $pdf->SetTitle('Registration Report');
        $pdf->SetHeaderData('', 0, 'Registration Report', "Generated on: " . date('Y-m-d H:i:s'));
        $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
        $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
        $pdf->SetMargins(10, 20, 10);
        $pdf->AddPage();

        // Summary Data
        $html = "<h2>Convention Registration Summary Report</h2>
                <table border='1' cellpadding='5'>
                <tr><th>Total Children</th><th>Total Teens</th><th>Total Teachers</th><th>Total Amount Generated</th><th>Total Approved</th><th>Total Pending</th><th>Approval Rate (%)</th></tr>
                <tr><td>$p1</td><td>$p2</td><td>$p3</td><td>$p4</td><td>$approved_count</td><td>$pending_count</td><td>$approval_rate%</td></tr>
                </table><br><br>";

        // Detailed Data
        // if (!empty($data)) {
        //     $html .= "<h2>Detailed Registration Data</h2>
        //             <table border='1' cellpadding='5'>
        //             <tr>";
        //     foreach (array_keys($data[0]) as $column) {
        //         $html .= "<th>$column</th>";
        //     }
        //     $html .= "</tr>";
        //     foreach ($data as $row) {
        //         $html .= "<tr>";
        //         foreach ($row as $value) {
        //             $html .= "<td>$value</td>";
        //         }
        //         $html .= "</tr>";
        //     }
        //     $html .= "</table>";
        // } else {
        //     $html .= "<p>No data available.</p>";
        // }

        $pdf->writeHTML($html, true, false, true, false, '');
        $pdf->Output('registration_report.pdf', 'D');
        exit;
    }
}
?>
