<?php
session_start();
require_once 'conn.php'; // Include your database connection file

// Ensure the user is logged in and the chat_with parameter exists
if (!isset($_SESSION['admin_id']) || !isset($_GET['chat_with'])) {
    exit("Unauthorized access");
}

$admin_id = $_SESSION['admin_id']; // Get admin ID from session
$chat_with = $_GET['chat_with']; // Get the chat_with parameter from URL

// Variable to store any possible error message
$error_message = "";

// Store messages in a variable
$messages = [];

try {
    // Prepare the SQL statement to fetch messages between the current admin and the selected chat partner
    $stmt = $conn->prepare("SELECT m.*, a.username AS sender_name 
                            FROM admin_messages m 
                            JOIN admin a ON m.sender_id = a.id
                            WHERE (m.sender_id = :admin_id AND m.receiver_id = :chat_with) 
                            OR (m.sender_id = :chat_with AND m.receiver_id = :admin_id) 
                            ORDER BY m.sent_at ASC");

    // Bind the parameters correctly
    $stmt->bindParam(':admin_id', $admin_id, PDO::PARAM_INT);
    $stmt->bindParam(':chat_with', $chat_with, PDO::PARAM_INT);

    // Execute the query
    $stmt->execute();

    // Fetch all messages for the chat
    $messages = $stmt->fetchAll(PDO::FETCH_ASSOC); 

} catch (PDOException $e) {
    // Log the error message to a file for debugging (hidden from user)
    file_put_contents('error_log.txt', "Error fetching messages: " . $e->getMessage() . "\n", FILE_APPEND);
}

// Display the messages or an empty response
if (!empty($messages)) {
    // Loop through the messages and display them
    foreach ($messages as $msg): ?>
        <div class="chat-message p-2 mb-2 <?= ($msg['sender_id'] == $admin_id) ? 'sent text-end bg-success text-white rounded' : 'received bg-light text-dark rounded'; ?>">
            <strong><?= htmlspecialchars($msg['sender_name']); ?>:</strong>
            <p><?= nl2br(htmlspecialchars($msg['message'])); ?></p>
            <small class="message-status d-block text-muted">
                <?= date('h:i A', strtotime($msg['sent_at'])); ?> - 
                <?php if ($msg['status'] == 'sent'): ?>📩 Sent
                <?php elseif ($msg['status'] == 'delivered'): ?>📬 Delivered
                <?php else: ?>✔ Read
                <?php endif; ?>
            </small>
        </div>
    <?php endforeach;
} else {
    // Optionally, you can display a placeholder message here if no messages are found
    // echo "<p>No messages found.</p>";
}
?>
