<?php

require_once("../session.php");

if (!isset($_SESSION['dashboard'])) {
    echo "<script>alert('Please Kindly Login to gain control...'); location.href='../index.php';</script>";
    exit;
}

include("../conn.php");
$agent_id = $_SESSION['dashboard'];
$agent_name = $_SESSION['name'];
$f_region = $_POST['region'] ?? '';
$selected_year = $_POST['year'] ?? date('Y');

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['notification'])) {
    $province = $_POST['province'];
    $message = $_POST['message'];

    // Insert the notification into the database
    $stmt = $conn->prepare("INSERT INTO notifications (province, message) VALUES (:province, :message)");
    $stmt->bindValue(':province', $province);
    $stmt->bindValue(':message', $message);

    if ($stmt->execute()) {
        $successMessage = "Notification sent successfully!";
    } else {
        $errorMessage = "Failed to send notification.";
    }
}
// Send Notification to All Users
if (isset($_POST['send_notification'])) {
    $message = trim($_POST['message']);

    if (!empty($message)) {
        $stmt = $conn->prepare("INSERT INTO notifications (message, created_at, is_read) VALUES (:message, NOW(), 0)");
        $stmt->bindParam(':message', $message);

        if ($stmt->execute()) {
            $successMessage = "Notification sent successfully!";
        } else {
            $errorMessage = "Failed to send notification.";
        }
    } else {
        $errorMessage = "Notification message cannot be empty.";
    }
}

// Update Notification
if (isset($_POST['update_notification']) && !empty($_POST['notification_id'])) {
    $id = $_POST['notification_id'];
    $message = trim($_POST['message']);

    if (!empty($message)) {
        $stmt = $conn->prepare("UPDATE notifications SET message = :message WHERE id = :id");
        $stmt->bindParam(':message', $message);
        $stmt->bindParam(':id', $id);

        if ($stmt->execute()) {
            $successMessage = "Notification updated successfully!";
        } else {
            $errorMessage = "Failed to update notification.";
        }
    } else {
        $errorMessage = "Notification message cannot be empty.";
    }
}

// Edit Notification (Pre-fill the form)
if (isset($_GET['edit_notification'])) {
    $id = $_GET['edit_notification'];
    $stmt = $conn->prepare("SELECT * FROM notifications WHERE id = :id");
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    $editNotification = $stmt->fetch(PDO::FETCH_ASSOC);
}

// Delete Notification
if (isset($_GET['delete_notification'])) {
    $id = $_GET['delete_notification'];
    $stmt = $conn->prepare("DELETE FROM notifications WHERE id = :id");
    $stmt->bindParam(':id', $id);

    if ($stmt->execute()) {
        $successMessage = "Notification deleted successfully!";
    } else {
        $errorMessage = "Failed to delete notification.";
    }
}

// Delete All Notifications
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_all_notifications'])) {
    $stmt = $conn->prepare("DELETE FROM notifications");

    if ($stmt->execute()) {
        $successMessage = "All notifications deleted successfully!";
    } else {
        $errorMessage = "Failed to delete notifications.";
    }
}

?>

<!DOCTYPE html>
<html lang="en">

<head>
    <title>Send Notifications</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.4/css/dataTables.bootstrap5.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.4/js/dataTables.bootstrap5.min.js"></script>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
    <link rel="shortcut icon" type="image/x-icon" href="../images/icon2.png">

</head>

<body>
<div class="container mt-4">
    <div class="d-flex flex-wrap justify-content-between align-items-center mb-4 gap-2">
        <h2 class="text-primary">Send Notification (New Feature)</h2>
    </div>

    <div class="d-flex flex-wrap justify-content-center gap-3 mb-5">  <!-- Added mb-5 for more space -->
        <!-- Dark Mode Toggle -->
        <button id="themeToggle" class="btn btn-secondary">
            🌙 Dark Mode
        </button>

        <!-- Zone / Province Creation Button -->
        <a href="./zone.php" class="btn btn-info">
            <i class="bi bi-geo-alt-fill"></i> Zone / Province Creation
        </a>

        <!-- Send Notification Button -->
        <a href="./notification.php" class="btn btn-success">
            <i class="bi bi-bell-fill"></i> Send Notification
        </a>

        <!-- Payment Records Button -->
        <a href="./index.php" class="btn btn-warning">
            <i class="bi bi-cash-stack"></i> Payment Records
        </a>

        <!-- Logout Button -->
        <a href="../logout.php" class="btn btn-danger">
            <i class="bi bi-box-arrow-right"></i> Logout
        </a>
    </div>

    <!-- Increased space before the next card -->
    <div class="card p-3 mb-3">
        <h5 class="mb-2">Agent Details</h5>
        <p><strong>ID:</strong> <?php echo $agent_id; ?></p>
        <p><strong>Name:</strong> <?php echo $agent_name; ?></p>
    </div>


        <div class="container mt-5">
            <h2 class="text-center">Send Notification</h2>

            <div class="card">
                <div class="card-body">
                    <?php if (isset($successMessage)): ?>
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            <?php echo $successMessage; ?>
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                    <?php endif; ?>

                    <?php if (isset($errorMessage)): ?>
                        <div class="alert alert-danger alert-dismissible fade show" role="alert">
                            <?php echo $errorMessage; ?>
                            <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                    <?php endif; ?>

                    <script>
                        // Automatically dismiss alerts after 5 seconds
                        setTimeout(function() {
                            $('.alert').alert('close');
                        }, 5000); // Time in milliseconds
                    </script>


                    <form method="POST" action="notification.php">
                        <div class="form-group">
                            <label for="region">Region</label>
                            <select class="form-control" id="region" name="region" required>
                                <option value="">Select Region</option>
                                <?php for ($i = 1; $i <= 69; $i++): ?>
                                    <option value="<?php echo $i; ?>">Region <?php echo $i; ?></option>
                                <?php endfor; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="province">Province</label>
                            <select class="form-control" id="province" name="province" required>
                                <option value="">Select Province</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="message">Notification Message</label>
                            <textarea class="form-control" id="message" name="message" rows="4" required></textarea>
                        </div>
                        <!-- Added mt-3 for spacing -->
                        <button type="submit" name="notification" class="btn btn-primary mt-3">Send Notification</button>

                    </form>
                </div>
            </div>

            <div class="card mt-4">
                <div class="card-body">
                    <h3 class="text-center">All Notifications</h3>
                    <!-- Delete All Notifications Button -->
                    <form method="post" onsubmit="return confirm('Are you sure you want to delete all notifications?');">
                        <button type="submit" name="delete_all_notifications" class="btn btn-danger mb-3">Delete All Notifications</button>
                    </form>

                    <div class="table-responsive"> <!-- Added this div for mobile responsiveness -->
                        <table id="notificationsTable" class="table table-bordered mt-3">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Message</th>
                                    <th>Province</th>
                                    <th>Created At</th>
                                    <th>Status</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                // Fetch notifications for admin
                                $stmt = $conn->prepare("SELECT n.id, n.message, n.province, n.created_at, n.is_read FROM notifications n");
                                $stmt->execute();
                                $notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);

                                foreach ($notifications as $notification): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($notification['id']); ?></td>
                                        <td><?php echo htmlspecialchars($notification['message']); ?></td>
                                        <td><?php echo htmlspecialchars($notification['province']); ?></td>
                                        <td><?php echo date('jS M, Y', strtotime($notification['created_at'])); ?></td>
                                        <td>
                                            <?php if ($notification['is_read']): ?>
                                                <span class="badge badge-success">Read</span>
                                            <?php else: ?>
                                                <span class="badge badge-danger">Unread</span>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>



            <!----General Notification----->
            <div class="container mt-5">
                <h2 class="text-center">Edit Notification to Coordinators</h2>

                <div class="card">
                    <div class="card-body">
                        <?php if (isset($successMessage)): ?>
                            <div class="alert alert-success alert-dismissible fade show" role="alert">
                                <?php echo $successMessage; ?>
                                <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                    <span aria-hidden="true">&times;</span>
                                </button>
                            </div>
                        <?php endif; ?>

                        <?php if (isset($errorMessage)): ?>
                            <div class="alert alert-danger alert-dismissible fade show" role="alert">
                                <?php echo $errorMessage; ?>
                                <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                                    <span aria-hidden="true">&times;</span>
                                </button>
                            </div>
                        <?php endif; ?>

                        <script>
                            // Automatically dismiss alerts after 5 seconds
                            setTimeout(function() {
                                $('.alert').alert('close');
                            }, 5000);
                        </script>

                        <!-- Notification Form -->
                        <form method="POST" action="notification.php">
                            <input type="hidden" name="notification_id" value="<?php echo $editNotification['id'] ?? ''; ?>">

                            <div class="form-group">
                                <label for="message">Edit Notification Message</label>
                                <textarea class="form-control" id="message" name="message" rows="4" required><?php echo htmlspecialchars($editNotification['message'] ?? ''); ?></textarea>
                            </div>

                            <!-- Added mt-4 for more spacing -->
                            <button type="submit" name="<?php echo isset($editNotification) ? 'update_notification' : 'send_notification'; ?>"
                                class="btn btn-primary mt-4">
                                <?php echo isset($editNotification) ? 'Update Notification' : 'Send Notification'; ?>
                            </button>

                        </form>
                    </div>
                </div>

                <!-- Display All Notifications -->
                <div class="card mt-4">
                    <div class="card-body">
                        <h3 class="text-center">Edit/Delete Notifications</h3>

                        <!-- Delete All Notifications Button -->
                        <!-- <form method="post" onsubmit="return confirm('Are you sure you want to delete all notifications?');">
            <button type="submit" name="delete_all_notifications" class="btn btn-danger mb-3">Delete All Notifications</button>
        </form> -->

                        <div class="table-responsive">
                            <table id="notificationsTable2" class="table table-bordered mt-3">
                                <thead>
                                    <tr>
                                        <th>ID</th>
                                        <th>Message</th>
                                        <th>Created At</th>
                                        <th>Status</th>
                                        <th>Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php
                                    // Fetch all notifications
                                    $stmt = $conn->prepare("SELECT id, message, created_at, is_read FROM notifications");
                                    $stmt->execute();
                                    $notifications = $stmt->fetchAll(PDO::FETCH_ASSOC);

                                    foreach ($notifications as $notification): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($notification['id']); ?></td>
                                            <td><?php echo htmlspecialchars($notification['message']); ?></td>
                                            <td><?php echo date('jS M, Y', strtotime($notification['created_at'])); ?></td>
                                            <td>
                                                <?php if ($notification['is_read']): ?>
                                                    <span class="badge badge-success">Read</span>
                                                <?php else: ?>
                                                    <span class="badge badge-danger">Unread</span>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <a href="notification.php?edit_notification=<?php echo $notification['id']; ?>" class="btn btn-sm btn-warning">Edit</a>
                                                <a href="notification.php?delete_notification=<?php echo $notification['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('Are you sure you want to delete this notification?');">Delete</a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
<!-- Footer -->
<footer class="footer">
    &copy; <?php echo date("Y"); ?> PAYMENT AND REGISTRATION AGENT LOGIN. <br>
    <strong>Designed by Hi-Dev Solutions</strong>
</footer>

<style>
    .footer {
    width: 100%;
    text-align: center;
    padding: 15px 0;
    background-color: #f8f9fa; /* Light gray background */
    position: relative; /* Ensures it stays below content */
    margin-top: 30px; /* Adds spacing between body content and footer */
    font-size: 14px;
    font-weight: bold;
}

</style>

                <!-- Include jQuery and DataTables -->
                <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
                <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
                <link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/jquery.dataTables.min.css">

                <script>
                    $(document).ready(function() {
                        if (!$.fn.DataTable.isDataTable('#notificationsTable')) {
                            $('#notificationsTable2').DataTable({
                                "paging": true,
                                "lengthMenu": [10, 25, 50, 100], // Control number of entries per page
                                "ordering": true, // Enable sorting
                                "info": true, // Show table info
                                "searching": true, // Enable search box
                                "destroy": true // Allow reinitialization if needed
                            });
                        }
                    });
                </script>
                <script>
                    $(document).ready(function() {
                        if (!$.fn.DataTable.isDataTable('#notificationsTable')) {
                            $('#notificationsTable').DataTable({
                                "paging": true,
                                "lengthMenu": [10, 25, 50, 100], // Control number of entries per page
                                "ordering": true, // Enable sorting
                                "info": true, // Show table info
                                "searching": true, // Enable search box
                                "destroy": true // Allow reinitialization if needed
                            });
                        }
                    });
                </script>

                <!-- <script>
$(document).ready(function() {
    $('#notificationsTable').DataTable({
        "paging": true,
        "searching": true,
        "lengthChange": true,
        "pageLength": 10,
        "language": {
            "search": "Search Notifications:",
            "lengthMenu": "Show _MENU_ notifications per page"
        }
    });
});
</script> -->

                <script>
                    $('#region').change(function() {
                        let regionValue = $(this).val();
                        console.log("Selected Region: ", regionValue); // Debugging line
                        if (regionValue) {
                            $.ajax({
                                url: 'fetch_provinces.php',
                                type: 'GET',
                                data: {
                                    region: regionValue
                                },
                                dataType: 'json',
                                success: function(data) {
                                    console.log("Provinces Data: ", data); // Debugging line
                                    $('#province').empty().append('<option value="">Select Province</option>');
                                    data.forEach(function(province) {
                                        $('#province').append(`<option value="${province.province}">${province.province}</option>`);
                                    });
                                },
                                error: function() {
                                    alert('Error fetching provinces.');
                                }
                            });
                        } else {
                            $('#province').empty().append('<option value="">Select Province</option>');
                        }
                    });
                </script>


             <!-- Modal HTML -->
<div class="modal fade" id="welcomeModal" tabindex="-1" aria-labelledby="welcomeModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered"> <!-- Center Modal -->
        <div class="modal-content p-3 rounded shadow-lg">
            <div class="modal-header">
                <h5 class="modal-title fw-bold" id="welcomeModalLabel">🚀 Welcome to Payment Approval Page</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <p class="lead">Exciting updates to make your work easier:</p>
                <ul class="list-group list-group-flush">
                    <li class="list-group-item">✅ No more page refresh upon any payment approval; you will continue from where you are.</li>
                    <li class="list-group-item">✅ You can now demand a bank statement, upload the CSV, and the system will approve all matched records in the database.</li>
                    <li class="list-group-item">✅ Your name will be saved as the approver if you upload such a CSV file.</li>
                    <hr>
                    <li class="list-group-item">📢 <strong>New Features Available:</strong></li>
                    <li class="list-group-item">✅ You can now send notification messages to different provinces.</li>
                    <li class="list-group-item">✅ You can delete multiple notifications at once or delete/edit individual notifications.</li>
                    <li class="list-group-item">✅ You can update provinces and regions, create new ones, and assign regions to zones.</li>
                    <li class="list-group-item">✅ You can now switch between <strong>Dark Mode</strong> and <strong>Light Mode</strong> for a better experience.</li>
                </ul>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-success w-100" data-bs-dismiss="modal" id="closeModal">🎉 Got it!</button>
            </div>
        </div>
    </div>
</div>

                <!-- JavaScript -->
                <script>
                    document.addEventListener("DOMContentLoaded", function() {
                        // Show modal only once
                        if (!localStorage.getItem("welcomeModalShown")) {
                            var welcomeModal = new bootstrap.Modal(document.getElementById("welcomeModal"));
                            welcomeModal.show();
                        }

                        document.getElementById("closeModal").addEventListener("click", function() {
                            localStorage.setItem("welcomeModalShown", "true");
                        });

                        // Dark Mode Toggle
                        const themeToggle = document.getElementById("themeToggle");
                        const body = document.body;
                        const cards = document.querySelectorAll(".card");

                        function setTheme(mode) {
                            if (mode === "dark") {
                                body.classList.add("dark-mode");
                                themeToggle.innerText = "☀️ Light Mode";
                                localStorage.setItem("theme", "dark");

                                // Change all cards to dark mode
                                cards.forEach(card => {
                                    card.classList.add("dark-card");
                                });
                            } else {
                                body.classList.remove("dark-mode");
                                themeToggle.innerText = "🌙 Dark Mode";
                                localStorage.setItem("theme", "light");

                                // Revert cards back to light mode
                                cards.forEach(card => {
                                    card.classList.remove("dark-card");
                                });
                            }
                        }

                        // Check saved theme preference
                        const savedTheme = localStorage.getItem("theme") || "light";
                        setTheme(savedTheme);

                        // Toggle theme on button click
                        themeToggle.addEventListener("click", function() {
                            const currentTheme = body.classList.contains("dark-mode") ? "light" : "dark";
                            setTheme(currentTheme);
                        });
                    });
                </script>

                <!-- Add Bootstrap & Custom CSS -->
                <style>
                    /* General Dark Mode */
                    .dark-mode {
                        background-color: #121212;
                        color: white;
                    }

                    /* Dark Mode for Modal */
                    .dark-mode .modal-content {
                        background-color: #1e1e1e;
                        color: white;
                        border: 1px solid #444;
                    }

                    .dark-mode .btn-close {
                        filter: invert(1);
                    }

                    /* Dark Mode for Cards */
                    .dark-card {
                        background-color: #000 !important;
                        color: white !important;
                        border: 1px solid #444;
                    }

                    /* Light Mode for Cards */
                    .card {
                        background-color: white;
                        color: black;
                        border: 1px solid #ddd;
                    }

                    /* Dark Mode for List Items */
                    .dark-mode .list-group-item {
                        background-color: #2a2a2a;
                        color: white;
                        border-color: #444;
                    }

                    /* Center the Modal */
                    .modal-dialog {
                        display: flex;
                        align-items: center;
                        min-height: 100vh;
                    }

                    .modal-content {
                        margin: auto;
                    }
                </style>

                <!-- Bootstrap JS -->
                <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

                <script>
                    $(document).ready(function() {
                        // Event delegation for Approve button
                        $(document).on("click", ".approve-btn", function(e) {
                            e.preventDefault();
                            let btn = $(this);
                            let rrr = btn.data("rrr");
                            let approved_by = "<?php echo $_SESSION['name']; ?>";

                            $.ajax({
                                url: "../verify.php",
                                type: "POST",
                                data: {
                                    rrr: rrr,
                                    approved_by: approved_by,
                                    action: "approve"
                                },
                                dataType: "json",
                                success: function(response) {
                                    alert(response.message);
                                    if (response.success) {
                                        $("#status_" + rrr).text("Approved");
                                        $("#row_" + rrr + " td:nth-child(8)").text(response.approved_by);
                                        btn.parent().html('<button class="btn btn-success" disabled>Approved</button> <button class="btn btn-danger revert-btn" data-rrr="' + rrr + '">Revert</button>');
                                    }
                                }
                            });
                        });

                        // Event delegation for Revert button
                        $(document).on("click", ".revert-btn", function(e) {
                            e.preventDefault();
                            let btn = $(this);
                            let rrr = btn.data("rrr");

                            if (!confirm("Are you sure you want to revert this payment to Pending?")) return;

                            $.ajax({
                                url: "../verify.php",
                                type: "POST",
                                data: {
                                    rrr: rrr,
                                    action: "revert"
                                },
                                dataType: "json",
                                success: function(response) {
                                    alert(response.message);
                                    if (response.success) {
                                        $("#status_" + rrr).text("Pending");
                                        $("#row_" + rrr + " td:nth-child(8)").text("");
                                        btn.parent().html('<button class="btn btn-warning approve-btn" data-rrr="' + rrr + '">Approve</button>');
                                    }
                                }
                            });
                        });
                    });
                </script>

</body>

</html>