<?php

require_once("../session.php");

if (!isset($_SESSION['dashboard'])) {
    echo "<script>alert('Please Kindly Login to gain control...'); location.href='../index.php';</script>";
    exit;
}

include("../conn.php");
$agent_id = $_SESSION['dashboard'];
$agent_name = $_SESSION['name'];
$f_region = $_POST['region'] ?? '';
$selected_year = $_POST['year'] ?? date('Y');
// ========= PASSWORD GENERATION FUNCTION =========
/**
 * Generates a password with the prefix 'dtce' followed by six random alphanumeric characters.
 *
 * @return string The generated password.
 */
function generatePassword()
{
    $prefix = 'dtce';
    $length = 6;
    $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[random_int(0, $charactersLength - 1)];
    }
    return $prefix . $randomString;
}

// ========= AJAX ENDPOINTS =========

// If action is get_regions, return JSON of distinct regions.
if (isset($_GET['action']) && $_GET['action'] == 'get_regions') {
    $stmt = $conn->query("SELECT DISTINCT region FROM province ORDER BY region ASC");
    $regions = $stmt->fetchAll(PDO::FETCH_COLUMN);
    echo json_encode($regions);
    exit;
}

// If action is update_zones, update provinces by region.
if (isset($_POST['action']) && $_POST['action'] == 'update_zones') {
    header('Content-Type: application/json');
    if (isset($_POST['zone']) && isset($_POST['region'])) {
        $zone   = $_POST['zone'];
        $region = $_POST['region'];

        // Update the province records with the chosen zone.
        $stmt = $conn->prepare("UPDATE province SET zone = :zone WHERE region = :region");
        $stmt->execute(['zone' => $zone, 'region' => $region]);

        // Retrieve updated records.
        $stmt2 = $conn->prepare("SELECT province, password FROM province WHERE region = :region");
        $stmt2->execute(['region' => $region]);
        $updated = $stmt2->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode(['success' => true, 'updated' => $updated]);
    } else {
        echo json_encode(['success' => false, 'message' => 'Zone and region are required.']);
    }
    exit;
}

// If action is add_province, process new record submission.
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] == 'add_province') {
    $region   = trim($_POST['region']);
    $province = trim($_POST['province']);

    if (empty($region) || empty($province)) {
        $message = '<div class="alert alert-danger">Please fill in all fields.</div>';
    } else {
        // Generate the password automatically
        $password = generatePassword();

        $stmt = $conn->prepare("INSERT INTO province (region, province, password, zone) VALUES (:region, :province, :password, '')");
        if ($stmt->execute(['region' => $region, 'province' => $province, 'password' => $password])) {
            $message = '<div class="alert alert-success" id="success-alert">New province/region record added successfully! Generated Password: ' . htmlspecialchars($password) . '</div>';
        } else {
            $message = '<div class="alert alert-danger" id="error-alert">Error adding new record.</div>';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <title>New Zone and Province Creation</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.4/css/dataTables.bootstrap5.min.css">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.4/js/dataTables.bootstrap5.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">
    <link rel="shortcut icon" type="image/x-icon" href="../images/icon2.png">
</head>

<body>
    <div class="container mt-4">
        <div class="d-flex flex-wrap justify-content-between align-items-center mb-4 gap-2">
            <h2 class="text-primary">Zone/Province/Region Creation (New Feature)</h2>
        </div>

        <div class="d-flex flex-wrap justify-content-center gap-3 mb-5"> <!-- Added mb-5 for more space -->
            <!-- Dark Mode Toggle -->
            <button id="themeToggle" class="btn btn-secondary">
                🌙 Dark Mode
            </button>

            <!-- Zone / Province Creation Button -->
            <a href="./zone.php" class="btn btn-info">
                <i class="bi bi-geo-alt-fill"></i> Zone / Province Creation
            </a>

            <!-- Send Notification Button -->
            <a href="./notification.php" class="btn btn-success">
                <i class="bi bi-bell-fill"></i> Send Notification
            </a>

            <!-- Payment Records Button -->
            <a href="./index.php" class="btn btn-warning">
                <i class="bi bi-cash-stack"></i> Payment Records
            </a>

            <!-- Logout Button -->
            <a href="../logout.php" class="btn btn-danger">
                <i class="bi bi-box-arrow-right"></i> Logout
            </a>
        </div>

        <!-- Increased space before the next card -->
        <div class="card p-3 mb-3">
            <h5 class="mb-2">Agent Details</h5>
            <p><strong>ID:</strong> <?php echo $agent_id; ?></p>
            <p><strong>Name:</strong> <?php echo $agent_name; ?></p>
        </div>


        <div class="container">


            <!-- ========= ADD NEW RECORD SECTION ========= -->
            <div class="card">
                <div class="card-header bg-info text-white">
                    <h4>Add New Province/Region Record</h4>
                </div>
                <div class="card-body">
                    <?php if (!empty($message)) echo $message; ?>
                    <form method="POST" action="">
                        <input type="hidden" name="action" value="add_province">
                        <div class="form-group">
                            <label for="newRegion">Region</label>
                            <select name="region" id="newRegion" class="form-control" required>
                                <option value="">Select Region</option>
                                <!-- 1-69 options -->
                                <?php for ($i = 1; $i <= 69; $i++) : ?>
                                    <option value="<?php echo $i; ?>">Region <?php echo $i; ?></option>
                                <?php endfor; ?>
                                <!-- Specific named options -->
                                <option value="Redemption City">Redemption City</option>
                                <option value="Continental 1 Headquarters">Continental 1 Headquarters</option>
                                <option value="Continental 2 Headquarters">Continental 2 Headquarters</option>
                                <option value="Continental 3 Headquarters">Continental 3 Headquarters</option>
                                <option value="National Headquarters">National Headquarters</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="stateOrCapital">Select State or Capital or Region:</label><br>

                            <!-- Bootstrap custom radio buttons -->


                            <!-- Province Form -->
                            <div class="form-check">
                                <input type="radio" id="state" name="locationType" value="state" onclick="toggleLocation('state')" class="form-check-input">
                                <label for="state" class="form-check-label">State</label>
                            </div>

                            <div class="form-check">
                                <input type="radio" id="capital" name="locationType" value="capital" onclick="toggleLocation('capital')" class="form-check-input">
                                <label for="capital" class="form-check-label">Capital</label>
                            </div>

                            <div class="form-check">
                                <input type="radio" id="region" name="locationType" value="region" onclick="toggleLocation('region')" class="form-check-input">
                                <label for="region" class="form-check-label">Region</label>
                            </div>


                            <div class="form-group" id="states" style="display:none;">
                                <label for="state">Select State:</label><br>
                                <input type="checkbox" name="state" value="ABIA" onclick="generateProvince()"> ABIA<br>
                                <input type="checkbox" name="state" value="ADAMAWA" onclick="generateProvince()"> ADAMAWA<br>
                                <input type="checkbox" name="state" value="AKWA IBOM" onclick="generateProvince()"> AKWA IBOM<br>
                                <input type="checkbox" name="state" value="ANAMBRA" onclick="generateProvince()"> ANAMBRA<br>
                                <input type="checkbox" name="state" value="BAUCHI" onclick="generateProvince()"> BAUCHI<br>
                                <input type="checkbox" name="state" value="BAYELSA" onclick="generateProvince()"> BAYELSA<br>
                                <input type="checkbox" name="state" value="BENUE" onclick="generateProvince()"> BENUE<br>
                                <input type="checkbox" name="state" value="BORNO" onclick="generateProvince()"> BORNO<br>
                                <input type="checkbox" name="state" value="CROSS RIVER" onclick="generateProvince()"> CROSS RIVER<br>
                                <input type="checkbox" name="state" value="DELTA" onclick="generateProvince()"> DELTA<br>
                                <input type="checkbox" name="state" value="EBONYI" onclick="generateProvince()"> EBONYI<br>
                                <input type="checkbox" name="state" value="EDO" onclick="generateProvince()"> EDO<br>
                                <input type="checkbox" name="state" value="EKITI" onclick="generateProvince()"> EKITI<br>
                                <input type="checkbox" name="state" value="ENUGU" onclick="generateProvince()"> ENUGU<br>
                                <input type="checkbox" name="state" value="GOMBE" onclick="generateProvince()"> GOMBE<br>
                                <input type="checkbox" name="state" value="IMO" onclick="generateProvince()"> IMO<br>
                                <input type="checkbox" name="state" value="JIGAWA" onclick="generateProvince()"> JIGAWA<br>
                                <input type="checkbox" name="state" value="KADUNA" onclick="generateProvince()"> KADUNA<br>
                                <input type="checkbox" name="state" value="KANO" onclick="generateProvince()"> KANO<br>
                                <input type="checkbox" name="state" value="KATSINA" onclick="generateProvince()"> KATSINA<br>
                                <input type="checkbox" name="state" value="KEBBI" onclick="generateProvince()"> KEBBI<br>
                                <input type="checkbox" name="state" value="KOGI" onclick="generateProvince()"> KOGI<br>
                                <input type="checkbox" name="state" value="KWARA" onclick="generateProvince()"> KWARA<br>
                                <input type="checkbox" name="state" value="LAGOS" onclick="generateProvince()"> LAGOS<br>
                                <input type="checkbox" name="state" value="NASARAWA" onclick="generateProvince()"> NASARAWA<br>
                                <input type="checkbox" name="state" value="NIGER" onclick="generateProvince()"> NIGER<br>
                                <input type="checkbox" name="state" value="OGUN" onclick="generateProvince()"> OGUN<br>
                                <input type="checkbox" name="state" value="ONDO" onclick="generateProvince()"> ONDO<br>
                                <input type="checkbox" name="state" value="OSUN" onclick="generateProvince()"> OSUN<br>
                                <input type="checkbox" name="state" value="OYO" onclick="generateProvince()"> OYO<br>
                                <input type="checkbox" name="state" value="PLATEAU" onclick="generateProvince()"> PLATEAU<br>
                                <input type="checkbox" name="state" value="RIVERS" onclick="generateProvince()"> RIVERS<br>
                                <input type="checkbox" name="state" value="SOKOTO" onclick="generateProvince()"> SOKOTO<br>
                                <input type="checkbox" name="state" value="TARABA" onclick="generateProvince()"> TARABA<br>
                                <input type="checkbox" name="state" value="YOBE" onclick="generateProvince()"> YOBE<br>
                                <input type="checkbox" name="state" value="ZAMFARA" onclick="generateProvince()"> ZAMFARA<br>
                            </div>

                            <div class="form-group" id="capitals" style="display:none;">
                                <label for="capital">Select Capital:</label><br>
                                <input type="checkbox" name="capital" value="ABUJA" onclick="generateProvince()"> ABUJA<br>
                                <input type="checkbox" name="capital" value="UMUAHIA" onclick="generateProvince()"> UMUAHIA (Abia)<br>
                                <input type="checkbox" name="capital" value="YOLA" onclick="generateProvince()"> YOLA (Adamawa)<br>
                                <input type="checkbox" name="capital" value="UYO" onclick="generateProvince()"> UYO (Akwa Ibom)<br>
                                <input type="checkbox" name="capital" value="AWKA" onclick="generateProvince()"> AWKA (Anambra)<br>
                                <input type="checkbox" name="capital" value="BAUCHI CITY" onclick="generateProvince()"> BAUCHI CITY (Bauchi)<br>
                                <input type="checkbox" name="capital" value="YENAGOA" onclick="generateProvince()"> YENAGOA (Bayelsa)<br>
                                <input type="checkbox" name="capital" value="MAKURDI" onclick="generateProvince()"> MAKURDI (Benue)<br>
                                <input type="checkbox" name="capital" value="MAIDUGURI" onclick="generateProvince()"> MAIDUGURI (Borno)<br>
                                <input type="checkbox" name="capital" value="CALABAR" onclick="generateProvince()"> CALABAR (Cross River)<br>
                                <input type="checkbox" name="capital" value="ASABA" onclick="generateProvince()"> ASABA (Delta)<br>
                                <input type="checkbox" name="capital" value="AWKA" onclick="generateProvince()"> AWKA (Ebonyi)<br>
                                <input type="checkbox" name="capital" value="BENIN CITY" onclick="generateProvince()"> BENIN CITY (Edo)<br>
                                <input type="checkbox" name="capital" value="ADO EKITI" onclick="generateProvince()"> ADO EKITI (Ekiti)<br>
                                <input type="checkbox" name="capital" value="ENUGU" onclick="generateProvince()"> ENUGU (Enugu)<br>
                                <input type="checkbox" name="capital" value="GOMBE" onclick="generateProvince()"> GOMBE (Gombe)<br>
                                <input type="checkbox" name="capital" value="IBADAN" onclick="generateProvince()"> IBADAN (Oyo)<br>
                                <input type="checkbox" name="capital" value="JOS" onclick="generateProvince()"> JOS (Plateau)<br>
                                <input type="checkbox" name="capital" value="KADUNA" onclick="generateProvince()"> KADUNA (Kaduna)<br>
                                <input type="checkbox" name="capital" value="KANO" onclick="generateProvince()"> KANO (Kano)<br>
                                <input type="checkbox" name="capital" value="KATSINA" onclick="generateProvince()"> KATSINA (Katsina)<br>
                                <input type="checkbox" name="capital" value="MAKURDI" onclick="generateProvince()"> MAKURDI (Benue)<br>
                                <input type="checkbox" name="capital" value="LAGOS" onclick="generateProvince()"> LAGOS (Lagos)<br>
                                <input type="checkbox" name="capital" value="MINNA" onclick="generateProvince()"> MINNA (Niger)<br>
                                <input type="checkbox" name="capital" value="NASSERAWA" onclick="generateProvince()"> NASSERAWA (Nasarawa)<br>
                                <input type="checkbox" name="capital" value="ONDO CITY" onclick="generateProvince()"> ONDO CITY (Ondo)<br>
                                <input type="checkbox" name="capital" value="OWERRI" onclick="generateProvince()"> OWERRI (Imo)<br>
                                <input type="checkbox" name="capital" value="PORT HARCOURT" onclick="generateProvince()"> PORT HARCOURT (Rivers)<br>
                                <input type="checkbox" name="capital" value="SOKOTO" onclick="generateProvince()"> SOKOTO (Sokoto)<br>
                                <input type="checkbox" name="capital" value="ABAKALIKI" onclick="generateProvince()"> ABAKALIKI (Ebonyi)<br>
                                <input type="checkbox" name="capital" value="TARABA" onclick="generateProvince()"> TARABA (Taraba)<br>
                                <input type="checkbox" name="capital" value="UMUAHIA" onclick="generateProvince()"> UMUAHIA (Abia)<br>
                                <input type="checkbox" name="capital" value="ZARIA" onclick="generateProvince()"> ZARIA (Kaduna)<br>
                                <input type="checkbox" name="capital" value="BAYELSA" onclick="generateProvince()"> BAYELSA (Bayelsa)<br>
                                <input type="checkbox" name="capital" value="BIDA" onclick="generateProvince()"> BIDA (Niger)<br>
                                <input type="checkbox" name="capital" value="DEMSA" onclick="generateProvince()"> DEMSA (Adamawa)<br>
                                <input type="checkbox" name="capital" value="EKITI" onclick="generateProvince()"> EKITI (Ekiti)<br>
                                <input type="checkbox" name="capital" value="AGUATA" onclick="generateProvince()"> AGUATA (Anambra)<br>
                                <input type="checkbox" name="capital" value="AKURE" onclick="generateProvince()"> AKURE (Ondo)<br>
                                <input type="checkbox" name="capital" value="OGUN" onclick="generateProvince()"> OGUN (Ogun)<br>
                                <input type="checkbox" name="capital" value="LAGOS" onclick="generateProvince()"> LAGOS CITY (Lagos)<br>
                                <input type="checkbox" name="capital" value="ZAMFARA" onclick="generateProvince()"> ZAMFARA (Zamfara)<br>
                                <input type="checkbox" name="capital" value="BENUE" onclick="generateProvince()"> BENUE (Benue)<br>

                                <!-- Add other capitals here -->
                            </div>
                            <!-- Region checkbox -->
                            <div class="form-group" id="regions" style="display:none;">
                                <label>Select Region:</label><br>
                                <input type="checkbox" name="region" value="1" onclick="generateProvince()"> REGION 1<br>
                                <input type="checkbox" name="region" value="2" onclick="generateProvince()"> REGION 2<br>
                                <input type="checkbox" name="region" value="3" onclick="generateProvince()"> REGION 3<br>
                                <input type="checkbox" name="region" value="4" onclick="generateProvince()"> REGION 4<br>
                                <input type="checkbox" name="region" value="5" onclick="generateProvince()"> REGION 5<br>
                                <input type="checkbox" name="region" value="6" onclick="generateProvince()"> REGION 6<br>
                                <input type="checkbox" name="region" value="7" onclick="generateProvince()"> REGION 7<br>
                                <input type="checkbox" name="region" value="8" onclick="generateProvince()"> REGION 8<br>
                                <input type="checkbox" name="region" value="9" onclick="generateProvince()"> REGION 9<br>
                                <input type="checkbox" name="region" value="10" onclick="generateProvince()"> REGION 10<br>
                                <input type="checkbox" name="region" value="11" onclick="generateProvince()"> REGION 11<br>
                                <input type="checkbox" name="region" value="12" onclick="generateProvince()"> REGION 12<br>
                                <input type="checkbox" name="region" value="13" onclick="generateProvince()"> REGION 13<br>
                                <input type="checkbox" name="region" value="14" onclick="generateProvince()"> REGION 14<br>
                                <input type="checkbox" name="region" value="15" onclick="generateProvince()"> REGION 15<br>
                                <input type="checkbox" name="region" value="16" onclick="generateProvince()"> REGION 16<br>
                                <input type="checkbox" name="region" value="17" onclick="generateProvince()"> REGION 17<br>
                                <input type="checkbox" name="region" value="18" onclick="generateProvince()"> REGION 18<br>
                                <input type="checkbox" name="region" value="19" onclick="generateProvince()"> REGION 19<br>
                                <input type="checkbox" name="region" value="20" onclick="generateProvince()"> REGION 20<br>
                                <input type="checkbox" name="region" value="21" onclick="generateProvince()"> REGION 21<br>
                                <input type="checkbox" name="region" value="22" onclick="generateProvince()"> REGION 22<br>
                                <input type="checkbox" name="region" value="23" onclick="generateProvince()"> REGION 23<br>
                                <input type="checkbox" name="region" value="24" onclick="generateProvince()"> REGION 24<br>
                                <input type="checkbox" name="region" value="25" onclick="generateProvince()"> REGION 25<br>
                                <input type="checkbox" name="region" value="26" onclick="generateProvince()"> REGION 26<br>
                                <input type="checkbox" name="region" value="27" onclick="generateProvince()"> REGION 27<br>
                                <input type="checkbox" name="region" value="28" onclick="generateProvince()"> REGION 28<br>
                                <input type="checkbox" name="region" value="29" onclick="generateProvince()"> REGION 29<br>
                                <input type="checkbox" name="region" value="30" onclick="generateProvince()"> REGION 30<br>
                                <input type="checkbox" name="region" value="31" onclick="generateProvince()"> REGION 31<br>
                                <input type="checkbox" name="region" value="32" onclick="generateProvince()"> REGION 32<br>
                                <input type="checkbox" name="region" value="33" onclick="generateProvince()"> REGION 33<br>
                                <input type="checkbox" name="region" value="34" onclick="generateProvince()"> REGION 34<br>
                                <input type="checkbox" name="region" value="35" onclick="generateProvince()"> REGION 35<br>
                                <input type="checkbox" name="region" value="36" onclick="generateProvince()"> REGION 36<br>
                                <input type="checkbox" name="region" value="37" onclick="generateProvince()"> REGION 37<br>
                                <input type="checkbox" name="region" value="38" onclick="generateProvince()"> REGION 38<br>
                                <input type="checkbox" name="region" value="39" onclick="generateProvince()"> REGION 39<br>
                                <input type="checkbox" name="region" value="40" onclick="generateProvince()"> REGION 40<br>
                                <input type="checkbox" name="region" value="41" onclick="generateProvince()"> REGION 41<br>
                                <input type="checkbox" name="region" value="42" onclick="generateProvince()"> REGION 42<br>
                                <input type="checkbox" name="region" value="43" onclick="generateProvince()"> REGION 43<br>
                                <input type="checkbox" name="region" value="44" onclick="generateProvince()"> REGION 44<br>
                                <input type="checkbox" name="region" value="45" onclick="generateProvince()"> REGION 45<br>
                                <input type="checkbox" name="region" value="46" onclick="generateProvince()"> REGION 46<br>
                                <input type="checkbox" name="region" value="47" onclick="generateProvince()"> REGION 47<br>
                                <input type="checkbox" name="region" value="48" onclick="generateProvince()"> REGION 48<br>
                                <input type="checkbox" name="region" value="49" onclick="generateProvince()"> REGION 49<br>
                                <input type="checkbox" name="region" value="50" onclick="generateProvince()"> REGION 50<br>
                                <input type="checkbox" name="region" value="51" onclick="generateProvince()"> REGION 51<br>
                                <input type="checkbox" name="region" value="52" onclick="generateProvince()"> REGION 52<br>
                                <input type="checkbox" name="region" value="53" onclick="generateProvince()"> REGION 53<br>
                                <input type="checkbox" name="region" value="54" onclick="generateProvince()"> REGION 54<br>
                                <input type="checkbox" name="region" value="55" onclick="generateProvince()"> REGION 55<br>
                                <input type="checkbox" name="region" value="56" onclick="generateProvince()"> REGION 56<br>
                                <input type="checkbox" name="region" value="57" onclick="generateProvince()"> REGION 57<br>
                                <input type="checkbox" name="region" value="58" onclick="generateProvince()"> REGION 58<br>
                                <input type="checkbox" name="region" value="59" onclick="generateProvince()"> REGION 59<br>
                                <input type="checkbox" name="region" value="60" onclick="generateProvince()"> REGION 60<br>
                                <input type="checkbox" name="region" value="61" onclick="generateProvince()"> REGION 61<br>
                                <input type="checkbox" name="region" value="62" onclick="generateProvince()"> REGION 62<br>
                                <input type="checkbox" name="region" value="63" onclick="generateProvince()"> REGION 63<br>
                                <input type="checkbox" name="region" value="64" onclick="generateProvince()"> REGION 64<br>
                                <input type="checkbox" name="region" value="65" onclick="generateProvince()"> REGION 65<br>
                                <input type="checkbox" name="region" value="66" onclick="generateProvince()"> REGION 66<br>
                                <input type="checkbox" name="region" value="67" onclick="generateProvince()"> REGION 67<br>
                                <input type="checkbox" name="region" value="68" onclick="generateProvince()"> REGION 68<br>
                                <input type="checkbox" name="region" value="69" onclick="generateProvince()"> REGION 69<br>
                            </div>

                            <div class="form-group">
                                <label for="number">Select Number (1-150):</label><br>
                                <select id="number" onchange="generateProvince()" class="form-control">
                                    <option value="">--Select Number--</option>
                                    <!-- Generate options 1 to 150 dynamically -->
                                    <script>
                                        for (let i = 1; i <= 150; i++) {
                                            document.write('<option value="' + i + '">' + i + '</option>');
                                        }
                                    </script>
                                </select>
                            </div>
                            <div class="form-group mb-3"> <!-- Added mb-3 for spacing -->
                                <label for="province">Generated Province:</label>
                                <input type="text" id="province" class="form-control" name="province" readonly>
                            </div>

                            <button type="submit" class="btn btn-primary mt-3">Add Record</button> <!-- Added mt-3 -->

                    </form>
                </div>
            </div>

            <!-- ========= ASSIGN ZONE SECTION ========= -->
            <div class="card section-title p-3">
                <div class="card-header bg-primary text-white">
                    <h4>Assign Zone to Region</h4>
                </div>

                <div class="card-body">
                    <form id="zoneForm">
                        <div class="form-group">
                            <label for="zoneSelect"><strong>Select Zone:</strong></label>
                            <select id="zoneSelect" name="zone" class="form-control" required>
                                <option value="">-- Select Zone --</option>
                                <option value="Zone 1 – Lagos Regions">Zone 1 – Lagos Regions</option>
                                <option value="Zone 2 – Western Regions">Zone 2 – Western Regions</option>
                                <option value="Zone 3 – South – South Regions">Zone 3 – South – South Regions</option>
                                <option value="Zone 4 – Eastern Regions">Zone 4 – Eastern Regions</option>
                                <option value="Zone 5 – Northern Regions 1">Zone 5 – Northern Regions 1</option>
                                <option value="Zone 6 – Northern Regions 2">Zone 6 – Northern Regions 2</option>
                            </select>
                        </div>
                        <div class="form-group">
    <label><strong>Enter Region IDs (comma-separated):</strong></label>
    <textarea id="regionInput" class="form-control" rows="4" placeholder="E.g., 1, 2, 3, 7, 8, 9"></textarea>
</div>

<button type="button" id="assignZoneBtn" class="btn btn-primary mt-3">Assign Zone</button>
<div id="result" class="mt-3"></div>            </div>
        </div>

        <!-- Footer -->
        <footer class="footer">
            &copy; <?php echo date("Y"); ?> PAYMENT AND REGISTRATION AGENT LOGIN. <br>
            <strong>Designed by Hi-Dev Solutions</strong>
        </footer>

        <style>
            .footer {
                width: 100%;
                text-align: center;
                padding: 15px 0;
                background-color: #f8f9fa;
                /* Light gray background */
                position: relative;
                /* Ensures it stays below content */
                margin-top: 30px;
                /* Adds spacing between body content and footer */
                font-size: 14px;
                font-weight: bold;
            }
        </style>


        <!-- jQuery and Bootstrap JS (CDN) -->
        <script src="https://code.jquery.com/jquery-3.3.1.min.js"></script>
        <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"></script>

        <!-- DataTable JS -->
        <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
        <script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap5.min.js"></script>

        <!-- Bootstrap JS -->
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>

        <script>
            // Toggle visibility based on location type (state/capital/region)
            function toggleLocation(locationType) {
                // Hide all options first
                document.getElementById('states').style.display = 'none';
                document.getElementById('capitals').style.display = 'none';
                document.getElementById('regions').style.display = 'none';

                // Show the relevant options
                if (locationType === 'state') {
                    document.getElementById('states').style.display = 'block';
                } else if (locationType === 'capital') {
                    document.getElementById('capitals').style.display = 'block';
                } else if (locationType === 'region') {
                    document.getElementById('regions').style.display = 'block';
                }

                // Clear previous province name
                document.getElementById('province').value = '';
            }

            // Generate province name based on selections
            function generateProvince() {
                let selectedLocation = '';
                let locationType = document.querySelector('input[name="locationType"]:checked');
                let number = document.getElementById('number').value;

                if (locationType) {
                    // Handle state or capital selections
                    if (locationType.value === 'state') {
                        const states = document.querySelectorAll('input[name="state"]:checked');
                        if (states.length === 1) {
                            selectedLocation = states[0].value + " PROVINCE " + number;
                        }
                    } else if (locationType.value === 'capital') {
                        const capitals = document.querySelectorAll('input[name="capital"]:checked');
                        if (capitals.length === 1) {
                            selectedLocation = capitals[0].value + " PROVINCE " + number;
                        }
                    } else if (locationType.value === 'region') {
                        const regions = document.querySelectorAll('input[name="region"]:checked');
                        if (regions.length === 1) {
                            selectedLocation = "REGION " + regions[0].value + " HEADQUARTERS";
                        }
                    }
                }

                // Set the generated province name in the input field
                document.getElementById('province').value = selectedLocation;
            }
        </script>
       <script>
$(document).ready(function () {
    $('#assignZoneBtn').on('click', function () {
        var selectedZone = $('#zoneSelect').val();
        var typedRegions = $('#regionInput').val().trim();

        if (!selectedZone) {
            alert('Please select a zone.');
            return;
        }
        if (!typedRegions) {
            alert('Please enter at least one region.');
            return;
        }

        // Convert regions string into an array, remove spaces, and allow text-based regions
        var regionsArray = typedRegions.split(',')
            .map(region => region.trim()) // Remove extra spaces
            .filter(region => region !== ''); // Ensure non-empty values

        $.ajax({
            url: 'update_zones.php',
            type: 'POST',
            data: {
                action: 'update_zones',
                zone: selectedZone,
                regions: regionsArray // Send array directly
            },
            dataType: 'json',
            success: function (response) {
                if (response.success) {
                    var html = '<div class="alert alert-success">Updated provinces in selected regions to zone <strong>' + selectedZone + '</strong>.</div>';
                    html += '<h5>Updated Provinces:</h5><ul class="list-group">';

                    $.each(response.updated, function (index, record) {
                        html += '<li class="list-group-item">' + record.province + ' (Password: ' + record.password + ')</li>';
                    });

                    html += '</ul>';
                    $('#result').html(html);
                } else {
                    $('#result').html('<div class="alert alert-danger">' + response.message + '</div>');
                }
            },
            error: function () {
                $('#result').html('<div class="alert alert-danger">Error updating provinces.</div>');
            }
        });
    });
});

</script>
        <script>
            // Automatically close the alert after 5 seconds
            setTimeout(function() {
                var alert = document.getElementById('success-alert') || document.getElementById('error-alert');
                if (alert) {
                    alert.style.display = 'none'; // Hide the alert
                }
            }, 5000); // 5000 milliseconds = 5 seconds
        </script>

        <!-- Modal HTML -->
        <div class="modal fade" id="welcomeModal" tabindex="-1" aria-labelledby="welcomeModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered"> <!-- Center Modal -->
                <div class="modal-content p-3 rounded shadow-lg">
                    <div class="modal-header">
                        <h5 class="modal-title fw-bold" id="welcomeModalLabel">🚀 Welcome to Payment Approval Page</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <p class="lead">Exciting updates to make your work easier:</p>
                        <ul class="list-group list-group-flush">
                            <li class="list-group-item">✅ No more page refresh upon any payment approval; you will continue from where you are.</li>
                            <li class="list-group-item">✅ You can now demand a bank statement, upload the CSV, and the system will approve all matched records in the database.</li>
                            <li class="list-group-item">✅ Your name will be saved as the approver if you upload such a CSV file.</li>
                            <hr>
                            <li class="list-group-item">📢 <strong>New Features Available:</strong></li>
                            <li class="list-group-item">✅ You can now send notification messages to different provinces.</li>
                            <li class="list-group-item">✅ You can delete multiple notifications at once or delete/edit individual notifications.</li>
                            <li class="list-group-item">✅ You can update provinces and regions, create new ones, and assign regions to zones.</li>
                            <li class="list-group-item">✅ You can now switch between <strong>Dark Mode</strong> and <strong>Light Mode</strong> for a better experience.</li>
                        </ul>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-success w-100" data-bs-dismiss="modal" id="closeModal">🎉 Got it!</button>
                    </div>
                </div>
            </div>
        </div>

        <!-- JavaScript -->
        <script>
            document.addEventListener("DOMContentLoaded", function() {
                // Show modal only once
                if (!localStorage.getItem("welcomeModalShown")) {
                    var welcomeModal = new bootstrap.Modal(document.getElementById("welcomeModal"));
                    welcomeModal.show();
                }

                document.getElementById("closeModal").addEventListener("click", function() {
                    localStorage.setItem("welcomeModalShown", "true");
                });

                // Dark Mode Toggle
                const themeToggle = document.getElementById("themeToggle");
                const body = document.body;
                const cards = document.querySelectorAll(".card");

                function setTheme(mode) {
                    if (mode === "dark") {
                        body.classList.add("dark-mode");
                        themeToggle.innerText = "☀️ Light Mode";
                        localStorage.setItem("theme", "dark");

                        // Change all cards to dark mode
                        cards.forEach(card => {
                            card.classList.add("dark-card");
                        });
                    } else {
                        body.classList.remove("dark-mode");
                        themeToggle.innerText = "🌙 Dark Mode";
                        localStorage.setItem("theme", "light");

                        // Revert cards back to light mode
                        cards.forEach(card => {
                            card.classList.remove("dark-card");
                        });
                    }
                }

                // Check saved theme preference
                const savedTheme = localStorage.getItem("theme") || "light";
                setTheme(savedTheme);

                // Toggle theme on button click
                themeToggle.addEventListener("click", function() {
                    const currentTheme = body.classList.contains("dark-mode") ? "light" : "dark";
                    setTheme(currentTheme);
                });
            });
        </script>

        <!-- Add Bootstrap & Custom CSS -->
        <style>
            /* General Dark Mode */
            .dark-mode {
                background-color: #121212;
                color: white;
            }

            /* Dark Mode for Modal */
            .dark-mode .modal-content {
                background-color: #1e1e1e;
                color: white;
                border: 1px solid #444;
            }

            .dark-mode .btn-close {
                filter: invert(1);
            }

            /* Dark Mode for Cards */
            .dark-card {
                background-color: #000 !important;
                color: white !important;
                border: 1px solid #444;
            }

            /* Light Mode for Cards */
            .card {
                background-color: white;
                color: black;
                border: 1px solid #ddd;
            }

            /* Dark Mode for List Items */
            .dark-mode .list-group-item {
                background-color: #2a2a2a;
                color: white;
                border-color: #444;
            }

            /* Center the Modal */
            .modal-dialog {
                display: flex;
                align-items: center;
                min-height: 100vh;
            }

            .modal-content {
                margin: auto;
            }
        </style>

        <!-- Bootstrap JS -->
        <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

        <script>
            $(document).ready(function() {
                // Event delegation for Approve button
                $(document).on("click", ".approve-btn", function(e) {
                    e.preventDefault();
                    let btn = $(this);
                    let rrr = btn.data("rrr");
                    let approved_by = "<?php echo $_SESSION['name']; ?>";

                    $.ajax({
                        url: "../verify.php",
                        type: "POST",
                        data: {
                            rrr: rrr,
                            approved_by: approved_by,
                            action: "approve"
                        },
                        dataType: "json",
                        success: function(response) {
                            alert(response.message);
                            if (response.success) {
                                $("#status_" + rrr).text("Approved");
                                $("#row_" + rrr + " td:nth-child(8)").text(response.approved_by);
                                btn.parent().html('<button class="btn btn-success" disabled>Approved</button> <button class="btn btn-danger revert-btn" data-rrr="' + rrr + '">Revert</button>');
                            }
                        }
                    });
                });

                // Event delegation for Revert button
                $(document).on("click", ".revert-btn", function(e) {
                    e.preventDefault();
                    let btn = $(this);
                    let rrr = btn.data("rrr");

                    if (!confirm("Are you sure you want to revert this payment to Pending?")) return;

                    $.ajax({
                        url: "../verify.php",
                        type: "POST",
                        data: {
                            rrr: rrr,
                            action: "revert"
                        },
                        dataType: "json",
                        success: function(response) {
                            alert(response.message);
                            if (response.success) {
                                $("#status_" + rrr).text("Pending");
                                $("#row_" + rrr + " td:nth-child(8)").text("");
                                btn.parent().html('<button class="btn btn-warning approve-btn" data-rrr="' + rrr + '">Approve</button>');
                            }
                        }
                    });
                });
            });
        </script>

</body>

</html>