<?php
// Start session and include database connection
session_start();
require_once "conn.php"; // Ensure this file contains your PDO connection setup

// Redirect to login if not logged in
if (!isset($_SESSION['login'])) {
    // Set the session variable for the alert message
    $_SESSION['alert_message'] = "You need to log as an Admin to gain Access!";

    // Redirect to the login page
    header("Location: admin_login.php");
    exit();
}
function generatePassword()
{
    $prefix = 'dtce';
    $length = 6;
    $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[random_int(0, $charactersLength - 1)];
    }
    return $prefix . $randomString;
}

// ========= AJAX ENDPOINTS =========

// If action is get_regions, return JSON of distinct regions.
if (isset($_GET['action']) && $_GET['action'] == 'get_regions') {
    $stmt = $conn->query("SELECT DISTINCT region FROM province ORDER BY region ASC");
    $regions = $stmt->fetchAll(PDO::FETCH_COLUMN);
    echo json_encode($regions);
    exit;
}

// If action is update_zones, update provinces by region.
if (isset($_POST['action']) && $_POST['action'] == 'update_zones') {
    header('Content-Type: application/json');
    if (isset($_POST['zone']) && isset($_POST['region'])) {
        $zone   = $_POST['zone'];
        $region = $_POST['region'];

        // Update the province records with the chosen zone.
        $stmt = $conn->prepare("UPDATE province SET zone = :zone WHERE region = :region");
        $stmt->execute(['zone' => $zone, 'region' => $region]);

        // Retrieve updated records.
        $stmt2 = $conn->prepare("SELECT province, password FROM province WHERE region = :region");
        $stmt2->execute(['region' => $region]);
        $updated = $stmt2->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode(['success' => true, 'updated' => $updated]);
    } else {
        echo json_encode(['success' => false, 'message' => 'Zone and region are required.']);
    }
    exit;
}

// If action is add_province, process new record submission.
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] == 'add_province') {
    $region   = trim($_POST['region']);
    $province = trim($_POST['province']);

    if (empty($region) || empty($province)) {
        $message = '<div class="alert alert-danger">Please fill in all fields.</div>';
    } else {
        // Generate the password automatically
        $password = generatePassword();

        $stmt = $conn->prepare("INSERT INTO province (region, province, password, zone) VALUES (:region, :province, :password, '')");
        if ($stmt->execute(['region' => $region, 'province' => $province, 'password' => $password])) {
            $message = '<div class="alert alert-success" id="success-alert">New province/region record added successfully! Generated Password: ' . htmlspecialchars($password) . '</div>';
        } else {
            $message = '<div class="alert alert-danger" id="error-alert">Error adding new record.</div>';
        }
    }
}
?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Super Admin Dashboard | RCCG</title>

    <!-- Dependencies -->
    <link rel="stylesheet" href="plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="dist/css/adminlte.min.css">
    <link rel="stylesheet" href="cookies/cookieconsent.css">
    <link rel="stylesheet" href="plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="dist/css/custom.css">
    <link rel="stylesheet" href="dist/css/login_style.css">
    <link rel="stylesheet" href="assets/css/mystyle.css">
    <link rel="stylesheet" href="dist/css/animate.min.css">
    <link href="plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons/font/bootstrap-icons.css">

    <!-- Include ApexCharts CSS -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.css">
    <link rel="shortcut icon" href="dist/img/icon2.png" type="image/x-icon">
    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>


    <style>
        /* General Styling for the Cards */
        .small-box {
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        /* Add Hover Effect on Cards: Zoom Effect */
        .small-box:hover {
            transform: scale(1.05);
            /* Zoom effect when hovering over the card */
            box-shadow: 0 8px 16px rgba(0, 0, 0, 0.2);
        }

        /* Animate cards when they appear on the screen */
        @keyframes fadeInUp {
            0% {
                opacity: 0;
                transform: translateY(30px);
            }

            100% {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .small-box {
            animation: fadeInUp 1s ease-out forwards;
        }

        /* Delayed animations for each card */
        .col-lg-3.col-md-6.col-12:nth-child(1) .small-box {
            animation-delay: 0.1s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(2) .small-box {
            animation-delay: 0.2s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(3) .small-box {
            animation-delay: 0.3s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(4) .small-box {
            animation-delay: 0.4s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(5) .small-box {
            animation-delay: 0.5s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(6) .small-box {
            animation-delay: 0.6s;
        }

        .col-lg-3.col-md-6.col-12:nth-child(7) .small-box {
            animation-delay: 0.7s;
        }

        .dark-mode {
            background-color: #222;
            color: white;
        }

        .dark-mode .navbar,
        .dark-mode .main-footer,
        .dark-mode .main-sidebar {
            background-color: #333 !important;
            color: white !important;
        }

        .dark-mode .main-sidebar .nav-link,
        .dark-mode .main-sidebar .brand-link,
        .dark-mode .main-footer {
            color: white !important;
        }

        .dark-mode .dropdown-menu {
            background-color: #444 !important;
            color: white !important;
        }

        .dark-mode .dropdown-item {
            color: white !important;
        }

        .dark-mode .dropdown-item:hover {
            background-color: #555 !important;
        }

        /* Dark Mode - Make All Cards Black */
        .dark-mode .card {
            background-color: #1e1e1e !important;
            border-color: #333 !important;
            color: #fff !important;
        }

        /* Ensure charts remain visible */
        .dark-mode .chart-container canvas {
            background-color: #1e1e1e !important;
        }

        /* Change chart labels and data to white */
        .dark-mode .chartjs-render-monitor {
            color: #fff !important;
        }

        /* Ensure Pie Chart is properly sized */
        #pieChart {
            max-width: 100% !important;
            height: 250px !important;
        }

        /* Ensure all text is readable in charts */
        .dark-mode .chart-container text {
            fill: #ffffff !important;
        }

        /* Adjust the Card Body Height */
        .card-body {
            height: 300px;
        }

        /* Tables in Dark Mode */
        .dark-mode table {
            background-color: #1e1e1e !important;
            color: #ffffff !important;
        }

        .dark-mode th,
        .dark-mode td {
            border-color: #444 !important;
        }

        /* Ensure buttons remain visible */
        .dark-mode .btn {
            background-color: #333 !important;
            color: #fff !important;
            border-color: #555 !important;
        }

        /* Navbar links in dark mode */
        .dark-mode .navbar a {
            color: #fff !important;
        }

        /* Navbar Gradient */
        .navbar-gradient {
            background: linear-gradient(45deg, #003366, #990000);
            animation: gradient 5s infinite alternate;
        }

        @keyframes gradient {
            0% {
                background-position: left;
            }

            100% {
                background-position: right;
            }
        }

        /* Show dropdown on hover */
        .nav-item.dropdown:hover .dropdown-menu {
            display: block;
            margin-top: 0;
        }

        .profile-circle {
            width: 35px;
            height: 35px;
            background-color: #007bff;
            color: white;
            font-weight: bold;
            display: flex;
            align-items: center;
            justify-content: center;
            border-radius: 50%;
            font-size: 16px;
            text-transform: uppercase;
        }
    </style>
</head>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">
        <!-- Navbar -->
        <nav class="main-header navbar navbar-expand-lg navbar-light navbar-gradient">
            <div class="container-fluid">
                <!-- Left side -->
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarContent">
                    <i class="fas fa-bars text-white"></i>
                </button>

                <a href="#" class="navbar-brand text-white d-lg-none">Manage Zone/Provinces</a>

                <div class="collapse navbar-collapse" id="navbarContent">
                    <ul class="navbar-nav me-auto">
                        <li class="nav-item d-none d-lg-block">
                            <a href="#" class="nav-link text-white">Manage Zone/Provinces</a>
                        </li>
                    </ul>

                    <!-- Search bar (hidden on small screens) -->
                    <form class="d-none d-lg-flex form-inline mx-auto">
                        <input class="form-control me-3 px-3 py-2" type="search" placeholder="Search" aria-label="Search">
                        <button class="btn btn-outline-primary px-3 py-2" type="submit">
                            <i class="fas fa-search"></i>
                        </button>
                    </form>


                    <!-- Right side -->
                    <ul class="navbar-nav ms-auto">
                        <!-- Search button (for mobile) -->
                        <li class="nav-item d-lg-none">
                            <a class="nav-link text-white" href="#" data-bs-toggle="collapse" data-bs-target="#searchBar">
                                <i class="fas fa-search"></i>
                            </a>
                        </li>

                        <!-- Collapsible search bar for mobile -->
                        <div class="collapse" id="searchBar">
                            <form class="d-flex my-2">
                                <input class="form-control me-2" type="search" placeholder="Search">
                                <button class="btn btn-outline-primary" type="submit">
                                    <i class="fas fa-search"></i>
                                </button>
                            </form>
                        </div>


                        <!-- Language Selector with Nigerian Flag -->
                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle text-white d-flex align-items-center" href="#" id="languageDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <img src="https://flagcdn.com/w40/ng.png" alt="Nigeria" width="25" class="me-3">
                                <span class="me-4 fw-bold">Nigeria</span> <!-- Increased spacing -->
                                <i class="fas fa-globe"></i> <span class="ms-3">Language</span> <!-- More space here -->
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end" aria-labelledby="languageDropdown">
                                <li><a class="dropdown-item" href="#" data-lang="en">English</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="fr">French</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="es">Spanish</a></li>
                                <li><a class="dropdown-item" href="#" data-lang="de">German</a></li>
                            </ul>
                        </li>



                        <!-- Dark mode toggle -->
                        <li class="nav-item">
                            <a class="nav-link text-white" id="toggleDarkMode">
                                <i class="fas fa-moon"></i>
                            </a>
                        </li>

                        <?php
                        // Get the username from the session
                        $username = isset($_SESSION['login']) ? $_SESSION['login'] : "Admin";

                        // Extract first and last letter (handle cases where username is too short)
                        $firstLetter = strtoupper($username[0]);
                        $lastLetter = strtoupper($username[strlen($username) - 1]);

                        // Profile initials
                        $profileInitials = $firstLetter . $lastLetter;
                        ?>

                        <li class="nav-item dropdown">
                            <a class="nav-link dropdown-toggle text-white d-flex align-items-center" href="#" id="userDropdown" data-bs-toggle="dropdown">
                                <div class="profile-circle me-2"><?php echo $profileInitials; ?></div>
                                <span><?php echo ucfirst($username); ?></span>
                            </a>
                            <ul class="dropdown-menu dropdown-menu-end">
                                <li><a class="dropdown-item" href="#">Profile</a></li>
                                <li><a class="dropdown-item" href="#">Settings</a></li>
                                <li>
                                    <hr class="dropdown-divider">
                                </li>
                                <li><a class="dropdown-item text-danger" href="logout.php">Logout</a></li>
                            </ul>
                        </li>

                    </ul>
                </div>
            </div>
        </nav>
    </div>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // Dark Mode Toggle
        document.getElementById("toggleDarkMode").addEventListener("click", function() {
            document.body.classList.toggle("dark-mode");
        });
    </script>

    <style>
        /* Global Dark Mode Styles */
        .dark-mode {
            background-color: #121212;
            /* Dark background for page */
            color: white;
            /* White text color */
        }

        /* Dark Mode Body */
        .dark-mode body {
            background-color: #121212;
            /* Black background for body */
            color: white;
            /* White text */
        }

        /* Dark Mode Navbar */
        .dark-mode .navbar {
            background: #1f1f1f;
            /* Darker background for navbar */
        }

        /* Dark Mode Sidebar */
        .dark-mode .main-sidebar {
            background-color: #1f1f1f;
            /* Dark background for sidebar */
        }

        .dark-mode .brand-link {
            background-color: #1f1f1f;
            /* Dark background for the brand */
            color: white;
            /* White text color for brand */
        }

        .dark-mode .nav-link {
            color: white;
            /* White text for nav links */
        }

        .dark-mode .nav-link:hover {
            background-color: #333;
            /* Darker background on hover */
        }

        /* Dark Mode Form Controls */
        .dark-mode .form-control,
        .dark-mode .form-select {
            background-color: #333;
            color: white;
            border: 1px solid #555;
        }

        /* Dark Mode Button */
        .dark-mode .btn-outline-primary {
            border-color: white;
            color: white;
        }

        /* Dark Mode Dropdown */
        .dark-mode .dropdown-menu {
            background-color: #222;
        }

        .dark-mode .dropdown-item {
            color: white;
        }

        .dark-mode .dropdown-item:hover {
            background-color: #333;
        }

        /* Dark Mode Cards */
        .dark-mode .small-box {
            background-color: #333;
            /* Dark background for cards */
            color: white;
            /* White text color */
        }

        .dark-mode .small-box .inner h3 {
            font-weight: bold;
            color: white;
            /* Make the text inside the card white */
        }

        .dark-mode .small-box .icon i {
            color: white;
            /* White icons inside the card */
        }

        /* Footer Adjustment for Dark Mode */
        footer.main-footer {
            position: relative;
            bottom: 0;
            width: 100%;
            margin-top: 50px;
            /* Adjust this value depending on how much space you need */
        }
    </style>

    </style>

    <!-- Sidebar -->
    <?php include('sidebar.php'); ?>

    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <!-- Breadcrumb -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Manage Zone/Provinces</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="#">Home</a></li>
                            <li class="breadcrumb-item active">Manage Zone/Provinces</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->

        <div class="container mt-4">




            <!-- Increased space before the next card -->



            <div class="container">


                <!-- ========= ADD NEW RECORD SECTION ========= -->
                <div class="card">
                    <div class="card-header bg-info text-white">
                        <h4>Add New Province/Region Record</h4>
                    </div>
                    <div class="card-body">
                        <?php if (!empty($message)) echo $message; ?>
                        <form method="POST" action="">
                            <input type="hidden" name="action" value="add_province">
                            <div class="form-group">
                                <label for="newRegion">Region</label>
                                <select name="region" id="newRegion" class="form-control" required>
                                    <option value="">Select Region</option>
                                    <!-- 1-69 options -->
                                    <?php for ($i = 1; $i <= 69; $i++) : ?>
                                        <option value="<?php echo $i; ?>">Region <?php echo $i; ?></option>
                                    <?php endfor; ?>
                                    <!-- Specific named options -->
                                    <option value="Redemption City">Redemption City</option>
                                    <option value="Continental 1 Headquarters">Continental 1 Headquarters</option>
                                    <option value="Continental 2 Headquarters">Continental 2 Headquarters</option>
                                    <option value="Continental 3 Headquarters">Continental 3 Headquarters</option>
                                    <option value="National Headquarters">National Headquarters</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="stateOrCapital">Select State or Capital or Region:</label><br>

                                <!-- Bootstrap custom radio buttons -->


                                <!-- Province Form -->
                                <div class="form-check">
                                    <input type="radio" id="state" name="locationType" value="state" onclick="toggleLocation('state')" class="form-check-input">
                                    <label for="state" class="form-check-label">State</label>
                                </div>

                                <div class="form-check">
                                    <input type="radio" id="capital" name="locationType" value="capital" onclick="toggleLocation('capital')" class="form-check-input">
                                    <label for="capital" class="form-check-label">Capital</label>
                                </div>

                                <div class="form-check">
                                    <input type="radio" id="region" name="locationType" value="region" onclick="toggleLocation('region')" class="form-check-input">
                                    <label for="region" class="form-check-label">Region</label>
                                </div>


                                <div class="form-group" id="states" style="display:none;">
                                    <label for="state">Select State:</label><br>
                                    <input type="checkbox" name="state" value="ABIA" onclick="generateProvince()"> ABIA<br>
                                    <input type="checkbox" name="state" value="ADAMAWA" onclick="generateProvince()"> ADAMAWA<br>
                                    <input type="checkbox" name="state" value="AKWA IBOM" onclick="generateProvince()"> AKWA IBOM<br>
                                    <input type="checkbox" name="state" value="ANAMBRA" onclick="generateProvince()"> ANAMBRA<br>
                                    <input type="checkbox" name="state" value="BAUCHI" onclick="generateProvince()"> BAUCHI<br>
                                    <input type="checkbox" name="state" value="BAYELSA" onclick="generateProvince()"> BAYELSA<br>
                                    <input type="checkbox" name="state" value="BENUE" onclick="generateProvince()"> BENUE<br>
                                    <input type="checkbox" name="state" value="BORNO" onclick="generateProvince()"> BORNO<br>
                                    <input type="checkbox" name="state" value="CROSS RIVER" onclick="generateProvince()"> CROSS RIVER<br>
                                    <input type="checkbox" name="state" value="DELTA" onclick="generateProvince()"> DELTA<br>
                                    <input type="checkbox" name="state" value="EBONYI" onclick="generateProvince()"> EBONYI<br>
                                    <input type="checkbox" name="state" value="EDO" onclick="generateProvince()"> EDO<br>
                                    <input type="checkbox" name="state" value="EKITI" onclick="generateProvince()"> EKITI<br>
                                    <input type="checkbox" name="state" value="ENUGU" onclick="generateProvince()"> ENUGU<br>
                                    <input type="checkbox" name="state" value="GOMBE" onclick="generateProvince()"> GOMBE<br>
                                    <input type="checkbox" name="state" value="IMO" onclick="generateProvince()"> IMO<br>
                                    <input type="checkbox" name="state" value="JIGAWA" onclick="generateProvince()"> JIGAWA<br>
                                    <input type="checkbox" name="state" value="KADUNA" onclick="generateProvince()"> KADUNA<br>
                                    <input type="checkbox" name="state" value="KANO" onclick="generateProvince()"> KANO<br>
                                    <input type="checkbox" name="state" value="KATSINA" onclick="generateProvince()"> KATSINA<br>
                                    <input type="checkbox" name="state" value="KEBBI" onclick="generateProvince()"> KEBBI<br>
                                    <input type="checkbox" name="state" value="KOGI" onclick="generateProvince()"> KOGI<br>
                                    <input type="checkbox" name="state" value="KWARA" onclick="generateProvince()"> KWARA<br>
                                    <input type="checkbox" name="state" value="LAGOS" onclick="generateProvince()"> LAGOS<br>
                                    <input type="checkbox" name="state" value="NASARAWA" onclick="generateProvince()"> NASARAWA<br>
                                    <input type="checkbox" name="state" value="NIGER" onclick="generateProvince()"> NIGER<br>
                                    <input type="checkbox" name="state" value="OGUN" onclick="generateProvince()"> OGUN<br>
                                    <input type="checkbox" name="state" value="ONDO" onclick="generateProvince()"> ONDO<br>
                                    <input type="checkbox" name="state" value="OSUN" onclick="generateProvince()"> OSUN<br>
                                    <input type="checkbox" name="state" value="OYO" onclick="generateProvince()"> OYO<br>
                                    <input type="checkbox" name="state" value="PLATEAU" onclick="generateProvince()"> PLATEAU<br>
                                    <input type="checkbox" name="state" value="RIVERS" onclick="generateProvince()"> RIVERS<br>
                                    <input type="checkbox" name="state" value="SOKOTO" onclick="generateProvince()"> SOKOTO<br>
                                    <input type="checkbox" name="state" value="TARABA" onclick="generateProvince()"> TARABA<br>
                                    <input type="checkbox" name="state" value="YOBE" onclick="generateProvince()"> YOBE<br>
                                    <input type="checkbox" name="state" value="ZAMFARA" onclick="generateProvince()"> ZAMFARA<br>
                                </div>

                                <div class="form-group" id="capitals" style="display:none;">
                                    <label for="capital">Select Capital:</label><br>
                                    <input type="checkbox" name="capital" value="ABUJA" onclick="generateProvince()"> ABUJA<br>
                                    <input type="checkbox" name="capital" value="UMUAHIA" onclick="generateProvince()"> UMUAHIA (Abia)<br>
                                    <input type="checkbox" name="capital" value="YOLA" onclick="generateProvince()"> YOLA (Adamawa)<br>
                                    <input type="checkbox" name="capital" value="UYO" onclick="generateProvince()"> UYO (Akwa Ibom)<br>
                                    <input type="checkbox" name="capital" value="AWKA" onclick="generateProvince()"> AWKA (Anambra)<br>
                                    <input type="checkbox" name="capital" value="BAUCHI CITY" onclick="generateProvince()"> BAUCHI CITY (Bauchi)<br>
                                    <input type="checkbox" name="capital" value="YENAGOA" onclick="generateProvince()"> YENAGOA (Bayelsa)<br>
                                    <input type="checkbox" name="capital" value="MAKURDI" onclick="generateProvince()"> MAKURDI (Benue)<br>
                                    <input type="checkbox" name="capital" value="MAIDUGURI" onclick="generateProvince()"> MAIDUGURI (Borno)<br>
                                    <input type="checkbox" name="capital" value="CALABAR" onclick="generateProvince()"> CALABAR (Cross River)<br>
                                    <input type="checkbox" name="capital" value="ASABA" onclick="generateProvince()"> ASABA (Delta)<br>
                                    <input type="checkbox" name="capital" value="AWKA" onclick="generateProvince()"> AWKA (Ebonyi)<br>
                                    <input type="checkbox" name="capital" value="BENIN CITY" onclick="generateProvince()"> BENIN CITY (Edo)<br>
                                    <input type="checkbox" name="capital" value="ADO EKITI" onclick="generateProvince()"> ADO EKITI (Ekiti)<br>
                                    <input type="checkbox" name="capital" value="ENUGU" onclick="generateProvince()"> ENUGU (Enugu)<br>
                                    <input type="checkbox" name="capital" value="GOMBE" onclick="generateProvince()"> GOMBE (Gombe)<br>
                                    <input type="checkbox" name="capital" value="IBADAN" onclick="generateProvince()"> IBADAN (Oyo)<br>
                                    <input type="checkbox" name="capital" value="JOS" onclick="generateProvince()"> JOS (Plateau)<br>
                                    <input type="checkbox" name="capital" value="KADUNA" onclick="generateProvince()"> KADUNA (Kaduna)<br>
                                    <input type="checkbox" name="capital" value="KANO" onclick="generateProvince()"> KANO (Kano)<br>
                                    <input type="checkbox" name="capital" value="KATSINA" onclick="generateProvince()"> KATSINA (Katsina)<br>
                                    <input type="checkbox" name="capital" value="MAKURDI" onclick="generateProvince()"> MAKURDI (Benue)<br>
                                    <input type="checkbox" name="capital" value="LAGOS" onclick="generateProvince()"> LAGOS (Lagos)<br>
                                    <input type="checkbox" name="capital" value="MINNA" onclick="generateProvince()"> MINNA (Niger)<br>
                                    <input type="checkbox" name="capital" value="NASSERAWA" onclick="generateProvince()"> NASSERAWA (Nasarawa)<br>
                                    <input type="checkbox" name="capital" value="ONDO CITY" onclick="generateProvince()"> ONDO CITY (Ondo)<br>
                                    <input type="checkbox" name="capital" value="OWERRI" onclick="generateProvince()"> OWERRI (Imo)<br>
                                    <input type="checkbox" name="capital" value="PORT HARCOURT" onclick="generateProvince()"> PORT HARCOURT (Rivers)<br>
                                    <input type="checkbox" name="capital" value="SOKOTO" onclick="generateProvince()"> SOKOTO (Sokoto)<br>
                                    <input type="checkbox" name="capital" value="ABAKALIKI" onclick="generateProvince()"> ABAKALIKI (Ebonyi)<br>
                                    <input type="checkbox" name="capital" value="TARABA" onclick="generateProvince()"> TARABA (Taraba)<br>
                                    <input type="checkbox" name="capital" value="UMUAHIA" onclick="generateProvince()"> UMUAHIA (Abia)<br>
                                    <input type="checkbox" name="capital" value="ZARIA" onclick="generateProvince()"> ZARIA (Kaduna)<br>
                                    <input type="checkbox" name="capital" value="BAYELSA" onclick="generateProvince()"> BAYELSA (Bayelsa)<br>
                                    <input type="checkbox" name="capital" value="BIDA" onclick="generateProvince()"> BIDA (Niger)<br>
                                    <input type="checkbox" name="capital" value="DEMSA" onclick="generateProvince()"> DEMSA (Adamawa)<br>
                                    <input type="checkbox" name="capital" value="EKITI" onclick="generateProvince()"> EKITI (Ekiti)<br>
                                    <input type="checkbox" name="capital" value="AGUATA" onclick="generateProvince()"> AGUATA (Anambra)<br>
                                    <input type="checkbox" name="capital" value="AKURE" onclick="generateProvince()"> AKURE (Ondo)<br>
                                    <input type="checkbox" name="capital" value="OGUN" onclick="generateProvince()"> OGUN (Ogun)<br>
                                    <input type="checkbox" name="capital" value="LAGOS" onclick="generateProvince()"> LAGOS CITY (Lagos)<br>
                                    <input type="checkbox" name="capital" value="ZAMFARA" onclick="generateProvince()"> ZAMFARA (Zamfara)<br>
                                    <input type="checkbox" name="capital" value="BENUE" onclick="generateProvince()"> BENUE (Benue)<br>

                                    <!-- Add other capitals here -->
                                </div>
                                <!-- Region checkbox -->
                                <div class="form-group" id="regions" style="display:none;">
                                    <label>Select Region:</label><br>
                                    <input type="checkbox" name="region" value="1" onclick="generateProvince()"> REGION 1<br>
                                    <input type="checkbox" name="region" value="2" onclick="generateProvince()"> REGION 2<br>
                                    <input type="checkbox" name="region" value="3" onclick="generateProvince()"> REGION 3<br>
                                    <input type="checkbox" name="region" value="4" onclick="generateProvince()"> REGION 4<br>
                                    <input type="checkbox" name="region" value="5" onclick="generateProvince()"> REGION 5<br>
                                    <input type="checkbox" name="region" value="6" onclick="generateProvince()"> REGION 6<br>
                                    <input type="checkbox" name="region" value="7" onclick="generateProvince()"> REGION 7<br>
                                    <input type="checkbox" name="region" value="8" onclick="generateProvince()"> REGION 8<br>
                                    <input type="checkbox" name="region" value="9" onclick="generateProvince()"> REGION 9<br>
                                    <input type="checkbox" name="region" value="10" onclick="generateProvince()"> REGION 10<br>
                                    <input type="checkbox" name="region" value="11" onclick="generateProvince()"> REGION 11<br>
                                    <input type="checkbox" name="region" value="12" onclick="generateProvince()"> REGION 12<br>
                                    <input type="checkbox" name="region" value="13" onclick="generateProvince()"> REGION 13<br>
                                    <input type="checkbox" name="region" value="14" onclick="generateProvince()"> REGION 14<br>
                                    <input type="checkbox" name="region" value="15" onclick="generateProvince()"> REGION 15<br>
                                    <input type="checkbox" name="region" value="16" onclick="generateProvince()"> REGION 16<br>
                                    <input type="checkbox" name="region" value="17" onclick="generateProvince()"> REGION 17<br>
                                    <input type="checkbox" name="region" value="18" onclick="generateProvince()"> REGION 18<br>
                                    <input type="checkbox" name="region" value="19" onclick="generateProvince()"> REGION 19<br>
                                    <input type="checkbox" name="region" value="20" onclick="generateProvince()"> REGION 20<br>
                                    <input type="checkbox" name="region" value="21" onclick="generateProvince()"> REGION 21<br>
                                    <input type="checkbox" name="region" value="22" onclick="generateProvince()"> REGION 22<br>
                                    <input type="checkbox" name="region" value="23" onclick="generateProvince()"> REGION 23<br>
                                    <input type="checkbox" name="region" value="24" onclick="generateProvince()"> REGION 24<br>
                                    <input type="checkbox" name="region" value="25" onclick="generateProvince()"> REGION 25<br>
                                    <input type="checkbox" name="region" value="26" onclick="generateProvince()"> REGION 26<br>
                                    <input type="checkbox" name="region" value="27" onclick="generateProvince()"> REGION 27<br>
                                    <input type="checkbox" name="region" value="28" onclick="generateProvince()"> REGION 28<br>
                                    <input type="checkbox" name="region" value="29" onclick="generateProvince()"> REGION 29<br>
                                    <input type="checkbox" name="region" value="30" onclick="generateProvince()"> REGION 30<br>
                                    <input type="checkbox" name="region" value="31" onclick="generateProvince()"> REGION 31<br>
                                    <input type="checkbox" name="region" value="32" onclick="generateProvince()"> REGION 32<br>
                                    <input type="checkbox" name="region" value="33" onclick="generateProvince()"> REGION 33<br>
                                    <input type="checkbox" name="region" value="34" onclick="generateProvince()"> REGION 34<br>
                                    <input type="checkbox" name="region" value="35" onclick="generateProvince()"> REGION 35<br>
                                    <input type="checkbox" name="region" value="36" onclick="generateProvince()"> REGION 36<br>
                                    <input type="checkbox" name="region" value="37" onclick="generateProvince()"> REGION 37<br>
                                    <input type="checkbox" name="region" value="38" onclick="generateProvince()"> REGION 38<br>
                                    <input type="checkbox" name="region" value="39" onclick="generateProvince()"> REGION 39<br>
                                    <input type="checkbox" name="region" value="40" onclick="generateProvince()"> REGION 40<br>
                                    <input type="checkbox" name="region" value="41" onclick="generateProvince()"> REGION 41<br>
                                    <input type="checkbox" name="region" value="42" onclick="generateProvince()"> REGION 42<br>
                                    <input type="checkbox" name="region" value="43" onclick="generateProvince()"> REGION 43<br>
                                    <input type="checkbox" name="region" value="44" onclick="generateProvince()"> REGION 44<br>
                                    <input type="checkbox" name="region" value="45" onclick="generateProvince()"> REGION 45<br>
                                    <input type="checkbox" name="region" value="46" onclick="generateProvince()"> REGION 46<br>
                                    <input type="checkbox" name="region" value="47" onclick="generateProvince()"> REGION 47<br>
                                    <input type="checkbox" name="region" value="48" onclick="generateProvince()"> REGION 48<br>
                                    <input type="checkbox" name="region" value="49" onclick="generateProvince()"> REGION 49<br>
                                    <input type="checkbox" name="region" value="50" onclick="generateProvince()"> REGION 50<br>
                                    <input type="checkbox" name="region" value="51" onclick="generateProvince()"> REGION 51<br>
                                    <input type="checkbox" name="region" value="52" onclick="generateProvince()"> REGION 52<br>
                                    <input type="checkbox" name="region" value="53" onclick="generateProvince()"> REGION 53<br>
                                    <input type="checkbox" name="region" value="54" onclick="generateProvince()"> REGION 54<br>
                                    <input type="checkbox" name="region" value="55" onclick="generateProvince()"> REGION 55<br>
                                    <input type="checkbox" name="region" value="56" onclick="generateProvince()"> REGION 56<br>
                                    <input type="checkbox" name="region" value="57" onclick="generateProvince()"> REGION 57<br>
                                    <input type="checkbox" name="region" value="58" onclick="generateProvince()"> REGION 58<br>
                                    <input type="checkbox" name="region" value="59" onclick="generateProvince()"> REGION 59<br>
                                    <input type="checkbox" name="region" value="60" onclick="generateProvince()"> REGION 60<br>
                                    <input type="checkbox" name="region" value="61" onclick="generateProvince()"> REGION 61<br>
                                    <input type="checkbox" name="region" value="62" onclick="generateProvince()"> REGION 62<br>
                                    <input type="checkbox" name="region" value="63" onclick="generateProvince()"> REGION 63<br>
                                    <input type="checkbox" name="region" value="64" onclick="generateProvince()"> REGION 64<br>
                                    <input type="checkbox" name="region" value="65" onclick="generateProvince()"> REGION 65<br>
                                    <input type="checkbox" name="region" value="66" onclick="generateProvince()"> REGION 66<br>
                                    <input type="checkbox" name="region" value="67" onclick="generateProvince()"> REGION 67<br>
                                    <input type="checkbox" name="region" value="68" onclick="generateProvince()"> REGION 68<br>
                                    <input type="checkbox" name="region" value="69" onclick="generateProvince()"> REGION 69<br>
                                </div>

                                <div class="form-group">
                                    <label for="number">Select Number (1-150):</label><br>
                                    <select id="number" onchange="generateProvince()" class="form-control">
                                        <option value="">--Select Number--</option>
                                        <!-- Generate options 1 to 150 dynamically -->
                                        <script>
                                            for (let i = 1; i <= 150; i++) {
                                                document.write('<option value="' + i + '">' + i + '</option>');
                                            }
                                        </script>
                                    </select>
                                </div>
                                <div class="form-group mb-3"> <!-- Added mb-3 for spacing -->
                                    <label for="province">Generated Province:</label>
                                    <input type="text" id="province" class="form-control" name="province" readonly>
                                </div>

                                <button type="submit" class="btn btn-primary mt-3">Add Record</button> <!-- Added mt-3 -->

                        </form>
                    </div>
                </div>

                <!-- ========= ASSIGN ZONE SECTION ========= -->


                <div class="card-header bg-primary text-white p-4" style="margin-bottom: 20px;">
                    <h4>Assign Zone to Region</h4>
                </div>

                <div class="card-body">
                    <form id="zoneForm">
                        <div class="form-group">
                            <label for="zoneSelect"><strong>Select Zone:</strong></label>
                            <select id="zoneSelect" name="zone" class="form-control" required>
                                <option value="">-- Select Zone --</option>
                                <option value="Zone 1 – Lagos Regions">Zone 1 – Lagos Regions</option>
                                <option value="Zone 2 – Western Regions">Zone 2 – Western Regions</option>
                                <option value="Zone 3 – South – South Regions">Zone 3 – South – South Regions</option>
                                <option value="Zone 4 – Eastern Regions">Zone 4 – Eastern Regions</option>
                                <option value="Zone 5 – Northern Regions 1">Zone 5 – Northern Regions 1</option>
                                <option value="Zone 6 – Northern Regions 2">Zone 6 – Northern Regions 2</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label><strong>Enter Region IDs (comma-separated):</strong></label>
                            <textarea id="regionInput" class="form-control" rows="4" placeholder="E.g., 1, 2, 3, 7, 8, 9"></textarea>
                        </div>

                        <button type="button" id="assignZoneBtn" class="btn btn-primary mt-3">Assign Zone</button>
                        <div id="result" class="mt-3"></div>
                    </form>
                </div>
            </div>



            <style>
                .footer {
                    width: 100%;
                    text-align: center;
                    padding: 15px 0;
                    background-color: #f8f9fa;
                    /* Light gray background */
                    position: relative;
                    /* Ensures it stays below content */
                    margin-top: 30px;
                    /* Adds spacing between body content and footer */
                    font-size: 14px;
                    font-weight: bold;
                }
            </style>
            <!-- jQuery and Bootstrap JS (CDN) -->
            <script src="https://code.jquery.com/jquery-3.3.1.min.js"></script>
            <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js"></script>

            <!-- DataTable JS -->
            <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
            <script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap5.min.js"></script>

            <!-- Bootstrap JS -->
            <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>

            <script>
                // Toggle visibility based on location type (state/capital/region)
                function toggleLocation(locationType) {
                    // Hide all options first
                    document.getElementById('states').style.display = 'none';
                    document.getElementById('capitals').style.display = 'none';
                    document.getElementById('regions').style.display = 'none';

                    // Show the relevant options
                    if (locationType === 'state') {
                        document.getElementById('states').style.display = 'block';
                    } else if (locationType === 'capital') {
                        document.getElementById('capitals').style.display = 'block';
                    } else if (locationType === 'region') {
                        document.getElementById('regions').style.display = 'block';
                    }

                    // Clear previous province name
                    document.getElementById('province').value = '';
                }

                // Generate province name based on selections
                function generateProvince() {
                    let selectedLocation = '';
                    let locationType = document.querySelector('input[name="locationType"]:checked');
                    let number = document.getElementById('number').value;

                    if (locationType) {
                        // Handle state or capital selections
                        if (locationType.value === 'state') {
                            const states = document.querySelectorAll('input[name="state"]:checked');
                            if (states.length === 1) {
                                selectedLocation = states[0].value + " PROVINCE " + number;
                            }
                        } else if (locationType.value === 'capital') {
                            const capitals = document.querySelectorAll('input[name="capital"]:checked');
                            if (capitals.length === 1) {
                                selectedLocation = capitals[0].value + " PROVINCE " + number;
                            }
                        } else if (locationType.value === 'region') {
                            const regions = document.querySelectorAll('input[name="region"]:checked');
                            if (regions.length === 1) {
                                selectedLocation = "REGION " + regions[0].value + " HEADQUARTERS";
                            }
                        }
                    }

                    // Set the generated province name in the input field
                    document.getElementById('province').value = selectedLocation;
                }
            </script>
            <script>
                $(document).ready(function() {
                    $('#assignZoneBtn').on('click', function() {
                        var selectedZone = $('#zoneSelect').val();
                        var typedRegions = $('#regionInput').val().trim();

                        if (!selectedZone) {
                            alert('Please select a zone.');
                            return;
                        }
                        if (!typedRegions) {
                            alert('Please enter at least one region.');
                            return;
                        }

                        // Convert regions string into an array, remove spaces, and allow text-based regions
                        var regionsArray = typedRegions.split(',')
                            .map(region => region.trim()) // Remove extra spaces
                            .filter(region => region !== ''); // Ensure non-empty values

                        $.ajax({
                            url: 'update_zones.php',
                            type: 'POST',
                            data: {
                                action: 'update_zones',
                                zone: selectedZone,
                                regions: regionsArray // Send array directly
                            },
                            dataType: 'json',
                            success: function(response) {
                                if (response.success) {
                                    var html = '<div class="alert alert-success">Updated provinces in selected regions to zone <strong>' + selectedZone + '</strong>.</div>';
                                    html += '<h5>Updated Provinces:</h5><ul class="list-group">';

                                    $.each(response.updated, function(index, record) {
                                        html += '<li class="list-group-item">' + record.province + ' (Password: ' + record.password + ')</li>';
                                    });

                                    html += '</ul>';
                                    $('#result').html(html);
                                } else {
                                    $('#result').html('<div class="alert alert-danger">' + response.message + '</div>');
                                }
                            },
                            error: function() {
                                $('#result').html('<div class="alert alert-danger">Error updating provinces.</div>');
                            }
                        });
                    });
                });
            </script>
            <script>
                // Automatically close the alert after 5 seconds
                setTimeout(function() {
                    var alert = document.getElementById('success-alert') || document.getElementById('error-alert');
                    if (alert) {
                        alert.style.display = 'none'; // Hide the alert
                    }
                }, 5000); // 5000 milliseconds = 5 seconds
            </script>


            <?php
            include 'conn.php'; // Ensure this file contains your database connection

            // Fetch footer content from the footer table
            $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
            $footer = $stmt->fetch(PDO::FETCH_ASSOC);
            $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
            $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
            ?>
            <br><br>
            <footer class="text-sm">
                <div class="text-xs" id="copyright">
                    <?php echo $copyrightMessage; ?>
                    <div class="float-right d-none d-sm-inline-block">
                        <b><?php echo $eventInfo; ?></b>
                    </div>
                </div>
            </footer>
            <!-- Modal -->
            <div class="modal fade" id="welcomeModal" tabindex="-1" aria-labelledby="welcomeModalLabel" aria-hidden="true">
                <div class="modal-dialog modal-dialog-centered modal-lg"> <!-- Add modal-lg class for larger size -->
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="welcomeModalLabel">Welcome to the New Admin Portal!</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" id="closeModalButton"></button>
                        </div>
                        <div class="modal-body">
                            <p>We are excited to introduce the new features in the admin portal, giving you greater control and enhanced functionality. Here's what's new:</p>
                            <ul>
                                <li><strong>Total Control of All Convention Portals</strong> – Manage all convention portals from a single dashboard.</li>
                                <li><strong>Approval of All Registrations</strong> – Full control over the approval process for registrations.</li>
                                <li><strong>New User Interface</strong> – A sleek, user-friendly interface to enhance your experience.</li>
                                <li><strong>General Report</strong> – Access to comprehensive reports to help you make informed decisions.</li>
                                <li><strong>Create Admins, Provinces, Regions, and Assign Regions to Zones</strong> – Full administrative control over users and regions.</li>
                                <li><strong>Create News and Notifications for All Coordinators</strong> – Easily manage news and notifications for all coordinators across the system.</li>
                            </ul>
                            <p>We hope you enjoy the enhanced experience and have all the tools you need to manage the portal effectively!</p>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                            <button type="button" class="btn btn-primary">Got It!</button>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Bootstrap JS and dependencies -->
            <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
            <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.min.js"></script>

            <script>
                // Check if the modal has been closed previously using localStorage
                if (!localStorage.getItem('modalClosed')) {
                    // Show the modal automatically when the page loads
                    var myModal = new bootstrap.Modal(document.getElementById('welcomeModal'));
                    myModal.show();
                }

                // Set the flag to not show the modal again once the user clicks close
                document.getElementById('closeModalButton').addEventListener('click', function() {
                    localStorage.setItem('modalClosed', 'true'); // Store flag to prevent modal from showing again
                });
            </script>


            <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
            <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
            <!-- Scripts -->
            <script src="plugins/jquery/jquery.min.js"></script>
            <script src="plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
            <script src="plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
            <script src="plugins/sweetalert2/sweetalert2.min.js"></script>
            <script src="plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
            <script src="dist/js/adminlte.min.js"></script>
            <script defer src="scripts/cookies/cookieconsent.js"></script>
            <script defer src="scripts/cookies/cookieconsent-init.js"></script>
            <script src="plugins/jquery-validation/jquery.validate.min.js"></script>
            <script src="plugins/jquery-validation/additional-methods.min.js"></script>
            <!-- Include jQuery and Bootstrap JS -->


            <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>


            <!-- Scripts -->
            <script>
                // Function to toggle dark mode and save preference
                function toggleDarkMode() {
                    $('body, .main-sidebar, .main-footer, .navbar, .card, .dropdown-menu, table, th, td').toggleClass('dark-mode');

                    let isDarkMode = $('body').hasClass('dark-mode');

                    // Store dark mode preference in localStorage
                    localStorage.setItem('darkMode', isDarkMode ? 'enabled' : 'disabled');

                    // Update icon
                    let icon = $('#toggleDarkMode').find('i');
                    icon.toggleClass('fa-moon fa-sun');
                }

                // Apply dark mode preference on page load
                $(document).ready(function() {
                    if (localStorage.getItem('darkMode') === 'enabled') {
                        $('body, .main-sidebar, .main-footer, .navbar, .card, .dropdown-menu, table, th, td').addClass('dark-mode');
                        $('#toggleDarkMode').find('i').removeClass('fa-moon').addClass('fa-sun'); // Ensure correct icon
                    }

                    // Toggle dark mode on button click
                    $('#toggleDarkMode').click(function() {
                        toggleDarkMode();
                    });

                    // Language selector (no change needed)
                    $('#languageSelector').change(function() {
                        let selectedLanguage = $(this).val();
                        alert("Language switched to: " + selectedLanguage);
                        // You can integrate a translation API here.
                    });
                });
            </script>



            <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>

</body>

</html>